# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #

from enum import Enum

from .api import API
from .base_object import BaseObject
from .errors import *
from .functions import *
from .types import *

BaseObject._all = {
    'accountTtl': AccountTtl,
    'address': Address,
    'animatedChatPhoto': AnimatedChatPhoto,
    'animation': Animation,
    'animations': Animations,
    'audio': Audio,
    'authenticationCodeInfo': AuthenticationCodeInfo,
    'authenticationCodeType': AuthenticationCodeType,
    'authenticationCodeTypeCall': AuthenticationCodeTypeCall,
    'authenticationCodeTypeFlashCall': AuthenticationCodeTypeFlashCall,
    'authenticationCodeTypeSms': AuthenticationCodeTypeSms,
    'authenticationCodeTypeTelegramMessage': AuthenticationCodeTypeTelegramMessage,
    'authorizationState': AuthorizationState,
    'authorizationStateClosed': AuthorizationStateClosed,
    'authorizationStateClosing': AuthorizationStateClosing,
    'authorizationStateLoggingOut': AuthorizationStateLoggingOut,
    'authorizationStateReady': AuthorizationStateReady,
    'authorizationStateWaitCode': AuthorizationStateWaitCode,
    'authorizationStateWaitEncryptionKey': AuthorizationStateWaitEncryptionKey,
    'authorizationStateWaitOtherDeviceConfirmation': AuthorizationStateWaitOtherDeviceConfirmation,
    'authorizationStateWaitPassword': AuthorizationStateWaitPassword,
    'authorizationStateWaitPhoneNumber': AuthorizationStateWaitPhoneNumber,
    'authorizationStateWaitRegistration': AuthorizationStateWaitRegistration,
    'authorizationStateWaitTdlibParameters': AuthorizationStateWaitTdlibParameters,
    'autoDownloadSettings': AutoDownloadSettings,
    'autoDownloadSettingsPresets': AutoDownloadSettingsPresets,
    'background': Background,
    'backgroundFill': BackgroundFill,
    'backgroundFillGradient': BackgroundFillGradient,
    'backgroundFillSolid': BackgroundFillSolid,
    'backgroundType': BackgroundType,
    'backgroundTypeFill': BackgroundTypeFill,
    'backgroundTypePattern': BackgroundTypePattern,
    'backgroundTypeWallpaper': BackgroundTypeWallpaper,
    'backgrounds': Backgrounds,
    'bankCardActionOpenUrl': BankCardActionOpenUrl,
    'bankCardInfo': BankCardInfo,
    'basicGroup': BasicGroup,
    'basicGroupFullInfo': BasicGroupFullInfo,
    'botCommand': BotCommand,
    'botInfo': BotInfo,
    'call': Call,
    'callDiscardReason': CallDiscardReason,
    'callDiscardReasonDeclined': CallDiscardReasonDeclined,
    'callDiscardReasonDisconnected': CallDiscardReasonDisconnected,
    'callDiscardReasonEmpty': CallDiscardReasonEmpty,
    'callDiscardReasonHungUp': CallDiscardReasonHungUp,
    'callDiscardReasonMissed': CallDiscardReasonMissed,
    'callId': CallId,
    'callProblem': CallProblem,
    'callProblemDistortedSpeech': CallProblemDistortedSpeech,
    'callProblemDistortedVideo': CallProblemDistortedVideo,
    'callProblemDropped': CallProblemDropped,
    'callProblemEcho': CallProblemEcho,
    'callProblemInterruptions': CallProblemInterruptions,
    'callProblemNoise': CallProblemNoise,
    'callProblemPixelatedVideo': CallProblemPixelatedVideo,
    'callProblemSilentLocal': CallProblemSilentLocal,
    'callProblemSilentRemote': CallProblemSilentRemote,
    'callProtocol': CallProtocol,
    'callServer': CallServer,
    'callServerType': CallServerType,
    'callServerTypeTelegramReflector': CallServerTypeTelegramReflector,
    'callServerTypeWebrtc': CallServerTypeWebrtc,
    'callState': CallState,
    'callStateDiscarded': CallStateDiscarded,
    'callStateError': CallStateError,
    'callStateExchangingKeys': CallStateExchangingKeys,
    'callStateHangingUp': CallStateHangingUp,
    'callStatePending': CallStatePending,
    'callStateReady': CallStateReady,
    'callbackQueryAnswer': CallbackQueryAnswer,
    'callbackQueryPayload': CallbackQueryPayload,
    'callbackQueryPayloadData': CallbackQueryPayloadData,
    'callbackQueryPayloadDataWithPassword': CallbackQueryPayloadDataWithPassword,
    'callbackQueryPayloadGame': CallbackQueryPayloadGame,
    'canTransferOwnershipResult': CanTransferOwnershipResult,
    'canTransferOwnershipResultOk': CanTransferOwnershipResultOk,
    'canTransferOwnershipResultPasswordNeeded': CanTransferOwnershipResultPasswordNeeded,
    'canTransferOwnershipResultPasswordTooFresh': CanTransferOwnershipResultPasswordTooFresh,
    'canTransferOwnershipResultSessionTooFresh': CanTransferOwnershipResultSessionTooFresh,
    'chat': Chat,
    'chatAction': ChatAction,
    'chatActionCancel': ChatActionCancel,
    'chatActionChoosingContact': ChatActionChoosingContact,
    'chatActionChoosingLocation': ChatActionChoosingLocation,
    'chatActionRecordingVideo': ChatActionRecordingVideo,
    'chatActionRecordingVideoNote': ChatActionRecordingVideoNote,
    'chatActionRecordingVoiceNote': ChatActionRecordingVoiceNote,
    'chatActionStartPlayingGame': ChatActionStartPlayingGame,
    'chatActionTyping': ChatActionTyping,
    'chatActionUploadingDocument': ChatActionUploadingDocument,
    'chatActionUploadingPhoto': ChatActionUploadingPhoto,
    'chatActionUploadingVideo': ChatActionUploadingVideo,
    'chatActionUploadingVideoNote': ChatActionUploadingVideoNote,
    'chatActionUploadingVoiceNote': ChatActionUploadingVoiceNote,
    'chatActionBar': ChatActionBar,
    'chatActionBarAddContact': ChatActionBarAddContact,
    'chatActionBarInviteMembers': ChatActionBarInviteMembers,
    'chatActionBarReportAddBlock': ChatActionBarReportAddBlock,
    'chatActionBarReportSpam': ChatActionBarReportSpam,
    'chatActionBarReportUnrelatedLocation': ChatActionBarReportUnrelatedLocation,
    'chatActionBarSharePhoneNumber': ChatActionBarSharePhoneNumber,
    'chatAdministrator': ChatAdministrator,
    'chatAdministrators': ChatAdministrators,
    'chatEvent': ChatEvent,
    'chatEventAction': ChatEventAction,
    'chatEventDescriptionChanged': ChatEventDescriptionChanged,
    'chatEventInviteLinkDeleted': ChatEventInviteLinkDeleted,
    'chatEventInviteLinkEdited': ChatEventInviteLinkEdited,
    'chatEventInviteLinkRevoked': ChatEventInviteLinkRevoked,
    'chatEventInvitesToggled': ChatEventInvitesToggled,
    'chatEventIsAllHistoryAvailableToggled': ChatEventIsAllHistoryAvailableToggled,
    'chatEventLinkedChatChanged': ChatEventLinkedChatChanged,
    'chatEventLocationChanged': ChatEventLocationChanged,
    'chatEventMemberInvited': ChatEventMemberInvited,
    'chatEventMemberJoined': ChatEventMemberJoined,
    'chatEventMemberJoinedByInviteLink': ChatEventMemberJoinedByInviteLink,
    'chatEventMemberLeft': ChatEventMemberLeft,
    'chatEventMemberPromoted': ChatEventMemberPromoted,
    'chatEventMemberRestricted': ChatEventMemberRestricted,
    'chatEventMessageDeleted': ChatEventMessageDeleted,
    'chatEventMessageEdited': ChatEventMessageEdited,
    'chatEventMessagePinned': ChatEventMessagePinned,
    'chatEventMessageTtlSettingChanged': ChatEventMessageTtlSettingChanged,
    'chatEventMessageUnpinned': ChatEventMessageUnpinned,
    'chatEventPermissionsChanged': ChatEventPermissionsChanged,
    'chatEventPhotoChanged': ChatEventPhotoChanged,
    'chatEventPollStopped': ChatEventPollStopped,
    'chatEventSignMessagesToggled': ChatEventSignMessagesToggled,
    'chatEventSlowModeDelayChanged': ChatEventSlowModeDelayChanged,
    'chatEventStickerSetChanged': ChatEventStickerSetChanged,
    'chatEventTitleChanged': ChatEventTitleChanged,
    'chatEventUsernameChanged': ChatEventUsernameChanged,
    'chatEventVoiceChatCreated': ChatEventVoiceChatCreated,
    'chatEventVoiceChatDiscarded': ChatEventVoiceChatDiscarded,
    'chatEventVoiceChatMuteNewParticipantsToggled': ChatEventVoiceChatMuteNewParticipantsToggled,
    'chatEventVoiceChatParticipantIsMutedToggled': ChatEventVoiceChatParticipantIsMutedToggled,
    'chatEventVoiceChatParticipantVolumeLevelChanged': ChatEventVoiceChatParticipantVolumeLevelChanged,
    'chatEventLogFilters': ChatEventLogFilters,
    'chatEvents': ChatEvents,
    'chatFilter': ChatFilter,
    'chatFilterInfo': ChatFilterInfo,
    'chatInviteLink': ChatInviteLink,
    'chatInviteLinkCount': ChatInviteLinkCount,
    'chatInviteLinkCounts': ChatInviteLinkCounts,
    'chatInviteLinkInfo': ChatInviteLinkInfo,
    'chatInviteLinkMember': ChatInviteLinkMember,
    'chatInviteLinkMembers': ChatInviteLinkMembers,
    'chatInviteLinks': ChatInviteLinks,
    'chatList': ChatList,
    'chatListArchive': ChatListArchive,
    'chatListFilter': ChatListFilter,
    'chatListMain': ChatListMain,
    'chatLists': ChatLists,
    'chatLocation': ChatLocation,
    'chatMember': ChatMember,
    'chatMemberStatus': ChatMemberStatus,
    'chatMemberStatusAdministrator': ChatMemberStatusAdministrator,
    'chatMemberStatusBanned': ChatMemberStatusBanned,
    'chatMemberStatusCreator': ChatMemberStatusCreator,
    'chatMemberStatusLeft': ChatMemberStatusLeft,
    'chatMemberStatusMember': ChatMemberStatusMember,
    'chatMemberStatusRestricted': ChatMemberStatusRestricted,
    'chatMembers': ChatMembers,
    'chatMembersFilter': ChatMembersFilter,
    'chatMembersFilterAdministrators': ChatMembersFilterAdministrators,
    'chatMembersFilterBanned': ChatMembersFilterBanned,
    'chatMembersFilterBots': ChatMembersFilterBots,
    'chatMembersFilterContacts': ChatMembersFilterContacts,
    'chatMembersFilterMembers': ChatMembersFilterMembers,
    'chatMembersFilterMention': ChatMembersFilterMention,
    'chatMembersFilterRestricted': ChatMembersFilterRestricted,
    'chatNearby': ChatNearby,
    'chatNotificationSettings': ChatNotificationSettings,
    'chatPermissions': ChatPermissions,
    'chatPhoto': ChatPhoto,
    'chatPhotoInfo': ChatPhotoInfo,
    'chatPhotos': ChatPhotos,
    'chatPosition': ChatPosition,
    'chatReportReason': ChatReportReason,
    'chatReportReasonChildAbuse': ChatReportReasonChildAbuse,
    'chatReportReasonCopyright': ChatReportReasonCopyright,
    'chatReportReasonCustom': ChatReportReasonCustom,
    'chatReportReasonFake': ChatReportReasonFake,
    'chatReportReasonPornography': ChatReportReasonPornography,
    'chatReportReasonSpam': ChatReportReasonSpam,
    'chatReportReasonUnrelatedLocation': ChatReportReasonUnrelatedLocation,
    'chatReportReasonViolence': ChatReportReasonViolence,
    'chatSource': ChatSource,
    'chatSourceMtprotoProxy': ChatSourceMtprotoProxy,
    'chatSourcePublicServiceAnnouncement': ChatSourcePublicServiceAnnouncement,
    'chatStatistics': ChatStatistics,
    'chatStatisticsChannel': ChatStatisticsChannel,
    'chatStatisticsSupergroup': ChatStatisticsSupergroup,
    'chatStatisticsAdministratorActionsInfo': ChatStatisticsAdministratorActionsInfo,
    'chatStatisticsInviterInfo': ChatStatisticsInviterInfo,
    'chatStatisticsMessageInteractionInfo': ChatStatisticsMessageInteractionInfo,
    'chatStatisticsMessageSenderInfo': ChatStatisticsMessageSenderInfo,
    'chatType': ChatType,
    'chatTypeBasicGroup': ChatTypeBasicGroup,
    'chatTypePrivate': ChatTypePrivate,
    'chatTypeSecret': ChatTypeSecret,
    'chatTypeSupergroup': ChatTypeSupergroup,
    'chats': Chats,
    'chatsNearby': ChatsNearby,
    'checkChatUsernameResult': CheckChatUsernameResult,
    'checkChatUsernameResultOk': CheckChatUsernameResultOk,
    'checkChatUsernameResultPublicChatsTooMuch': CheckChatUsernameResultPublicChatsTooMuch,
    'checkChatUsernameResultPublicGroupsUnavailable': CheckChatUsernameResultPublicGroupsUnavailable,
    'checkChatUsernameResultUsernameInvalid': CheckChatUsernameResultUsernameInvalid,
    'checkChatUsernameResultUsernameOccupied': CheckChatUsernameResultUsernameOccupied,
    'closedVectorPath': ClosedVectorPath,
    'connectedWebsite': ConnectedWebsite,
    'connectedWebsites': ConnectedWebsites,
    'connectionState': ConnectionState,
    'connectionStateConnecting': ConnectionStateConnecting,
    'connectionStateConnectingToProxy': ConnectionStateConnectingToProxy,
    'connectionStateReady': ConnectionStateReady,
    'connectionStateUpdating': ConnectionStateUpdating,
    'connectionStateWaitingForNetwork': ConnectionStateWaitingForNetwork,
    'contact': Contact,
    'count': Count,
    'countries': Countries,
    'countryInfo': CountryInfo,
    'customRequestResult': CustomRequestResult,
    'databaseStatistics': DatabaseStatistics,
    'date': Date,
    'dateRange': DateRange,
    'datedFile': DatedFile,
    'deepLinkInfo': DeepLinkInfo,
    'deviceToken': DeviceToken,
    'deviceTokenApplePush': DeviceTokenApplePush,
    'deviceTokenApplePushVoIP': DeviceTokenApplePushVoIP,
    'deviceTokenBlackBerryPush': DeviceTokenBlackBerryPush,
    'deviceTokenFirebaseCloudMessaging': DeviceTokenFirebaseCloudMessaging,
    'deviceTokenMicrosoftPush': DeviceTokenMicrosoftPush,
    'deviceTokenMicrosoftPushVoIP': DeviceTokenMicrosoftPushVoIP,
    'deviceTokenSimplePush': DeviceTokenSimplePush,
    'deviceTokenTizenPush': DeviceTokenTizenPush,
    'deviceTokenUbuntuPush': DeviceTokenUbuntuPush,
    'deviceTokenWebPush': DeviceTokenWebPush,
    'deviceTokenWindowsPush': DeviceTokenWindowsPush,
    'diceStickers': DiceStickers,
    'diceStickersRegular': DiceStickersRegular,
    'diceStickersSlotMachine': DiceStickersSlotMachine,
    'document': Document,
    'draftMessage': DraftMessage,
    'emailAddressAuthenticationCodeInfo': EmailAddressAuthenticationCodeInfo,
    'emojis': Emojis,
    'encryptedCredentials': EncryptedCredentials,
    'encryptedPassportElement': EncryptedPassportElement,
    'error': Error,
    'file': File,
    'filePart': FilePart,
    'fileType': FileType,
    'fileTypeAnimation': FileTypeAnimation,
    'fileTypeAudio': FileTypeAudio,
    'fileTypeDocument': FileTypeDocument,
    'fileTypeNone': FileTypeNone,
    'fileTypePhoto': FileTypePhoto,
    'fileTypeProfilePhoto': FileTypeProfilePhoto,
    'fileTypeSecret': FileTypeSecret,
    'fileTypeSecretThumbnail': FileTypeSecretThumbnail,
    'fileTypeSecure': FileTypeSecure,
    'fileTypeSticker': FileTypeSticker,
    'fileTypeThumbnail': FileTypeThumbnail,
    'fileTypeUnknown': FileTypeUnknown,
    'fileTypeVideo': FileTypeVideo,
    'fileTypeVideoNote': FileTypeVideoNote,
    'fileTypeVoiceNote': FileTypeVoiceNote,
    'fileTypeWallpaper': FileTypeWallpaper,
    'formattedText': FormattedText,
    'foundMessages': FoundMessages,
    'game': Game,
    'gameHighScore': GameHighScore,
    'gameHighScores': GameHighScores,
    'groupCall': GroupCall,
    'groupCallId': GroupCallId,
    'groupCallJoinResponse': GroupCallJoinResponse,
    'groupCallJoinResponseStream': GroupCallJoinResponseStream,
    'groupCallJoinResponseWebrtc': GroupCallJoinResponseWebrtc,
    'groupCallJoinResponseCandidate': GroupCallJoinResponseCandidate,
    'groupCallParticipant': GroupCallParticipant,
    'groupCallPayload': GroupCallPayload,
    'groupCallPayloadFingerprint': GroupCallPayloadFingerprint,
    'groupCallRecentSpeaker': GroupCallRecentSpeaker,
    'hashtags': Hashtags,
    'httpUrl': HttpUrl,
    'identityDocument': IdentityDocument,
    'importedContacts': ImportedContacts,
    'inlineKeyboardButton': InlineKeyboardButton,
    'inlineKeyboardButtonType': InlineKeyboardButtonType,
    'inlineKeyboardButtonTypeBuy': InlineKeyboardButtonTypeBuy,
    'inlineKeyboardButtonTypeCallback': InlineKeyboardButtonTypeCallback,
    'inlineKeyboardButtonTypeCallbackGame': InlineKeyboardButtonTypeCallbackGame,
    'inlineKeyboardButtonTypeCallbackWithPassword': InlineKeyboardButtonTypeCallbackWithPassword,
    'inlineKeyboardButtonTypeLoginUrl': InlineKeyboardButtonTypeLoginUrl,
    'inlineKeyboardButtonTypeSwitchInline': InlineKeyboardButtonTypeSwitchInline,
    'inlineKeyboardButtonTypeUrl': InlineKeyboardButtonTypeUrl,
    'inlineQueryResult': InlineQueryResult,
    'inlineQueryResultAnimation': InlineQueryResultAnimation,
    'inlineQueryResultArticle': InlineQueryResultArticle,
    'inlineQueryResultAudio': InlineQueryResultAudio,
    'inlineQueryResultContact': InlineQueryResultContact,
    'inlineQueryResultDocument': InlineQueryResultDocument,
    'inlineQueryResultGame': InlineQueryResultGame,
    'inlineQueryResultLocation': InlineQueryResultLocation,
    'inlineQueryResultPhoto': InlineQueryResultPhoto,
    'inlineQueryResultSticker': InlineQueryResultSticker,
    'inlineQueryResultVenue': InlineQueryResultVenue,
    'inlineQueryResultVideo': InlineQueryResultVideo,
    'inlineQueryResultVoiceNote': InlineQueryResultVoiceNote,
    'inlineQueryResults': InlineQueryResults,
    'inputBackground': InputBackground,
    'inputBackgroundLocal': InputBackgroundLocal,
    'inputBackgroundRemote': InputBackgroundRemote,
    'inputChatPhoto': InputChatPhoto,
    'inputChatPhotoAnimation': InputChatPhotoAnimation,
    'inputChatPhotoPrevious': InputChatPhotoPrevious,
    'inputChatPhotoStatic': InputChatPhotoStatic,
    'inputCredentials': InputCredentials,
    'inputCredentialsApplePay': InputCredentialsApplePay,
    'inputCredentialsGooglePay': InputCredentialsGooglePay,
    'inputCredentialsNew': InputCredentialsNew,
    'inputCredentialsSaved': InputCredentialsSaved,
    'inputFile': InputFile,
    'inputFileGenerated': InputFileGenerated,
    'inputFileId': InputFileId,
    'inputFileLocal': InputFileLocal,
    'inputFileRemote': InputFileRemote,
    'inputIdentityDocument': InputIdentityDocument,
    'inputInlineQueryResult': InputInlineQueryResult,
    'inputInlineQueryResultAnimation': InputInlineQueryResultAnimation,
    'inputInlineQueryResultArticle': InputInlineQueryResultArticle,
    'inputInlineQueryResultAudio': InputInlineQueryResultAudio,
    'inputInlineQueryResultContact': InputInlineQueryResultContact,
    'inputInlineQueryResultDocument': InputInlineQueryResultDocument,
    'inputInlineQueryResultGame': InputInlineQueryResultGame,
    'inputInlineQueryResultLocation': InputInlineQueryResultLocation,
    'inputInlineQueryResultPhoto': InputInlineQueryResultPhoto,
    'inputInlineQueryResultSticker': InputInlineQueryResultSticker,
    'inputInlineQueryResultVenue': InputInlineQueryResultVenue,
    'inputInlineQueryResultVideo': InputInlineQueryResultVideo,
    'inputInlineQueryResultVoiceNote': InputInlineQueryResultVoiceNote,
    'inputMessageContent': InputMessageContent,
    'inputMessageAnimation': InputMessageAnimation,
    'inputMessageAudio': InputMessageAudio,
    'inputMessageContact': InputMessageContact,
    'inputMessageDice': InputMessageDice,
    'inputMessageDocument': InputMessageDocument,
    'inputMessageForwarded': InputMessageForwarded,
    'inputMessageGame': InputMessageGame,
    'inputMessageInvoice': InputMessageInvoice,
    'inputMessageLocation': InputMessageLocation,
    'inputMessagePhoto': InputMessagePhoto,
    'inputMessagePoll': InputMessagePoll,
    'inputMessageSticker': InputMessageSticker,
    'inputMessageText': InputMessageText,
    'inputMessageVenue': InputMessageVenue,
    'inputMessageVideo': InputMessageVideo,
    'inputMessageVideoNote': InputMessageVideoNote,
    'inputMessageVoiceNote': InputMessageVoiceNote,
    'inputPassportElement': InputPassportElement,
    'inputPassportElementAddress': InputPassportElementAddress,
    'inputPassportElementBankStatement': InputPassportElementBankStatement,
    'inputPassportElementDriverLicense': InputPassportElementDriverLicense,
    'inputPassportElementEmailAddress': InputPassportElementEmailAddress,
    'inputPassportElementIdentityCard': InputPassportElementIdentityCard,
    'inputPassportElementInternalPassport': InputPassportElementInternalPassport,
    'inputPassportElementPassport': InputPassportElementPassport,
    'inputPassportElementPassportRegistration': InputPassportElementPassportRegistration,
    'inputPassportElementPersonalDetails': InputPassportElementPersonalDetails,
    'inputPassportElementPhoneNumber': InputPassportElementPhoneNumber,
    'inputPassportElementRentalAgreement': InputPassportElementRentalAgreement,
    'inputPassportElementTemporaryRegistration': InputPassportElementTemporaryRegistration,
    'inputPassportElementUtilityBill': InputPassportElementUtilityBill,
    'inputPassportElementError': InputPassportElementError,
    'inputPassportElementErrorSource': InputPassportElementErrorSource,
    'inputPassportElementErrorSourceDataField': InputPassportElementErrorSourceDataField,
    'inputPassportElementErrorSourceFile': InputPassportElementErrorSourceFile,
    'inputPassportElementErrorSourceFiles': InputPassportElementErrorSourceFiles,
    'inputPassportElementErrorSourceFrontSide': InputPassportElementErrorSourceFrontSide,
    'inputPassportElementErrorSourceReverseSide': InputPassportElementErrorSourceReverseSide,
    'inputPassportElementErrorSourceSelfie': InputPassportElementErrorSourceSelfie,
    'inputPassportElementErrorSourceTranslationFile': InputPassportElementErrorSourceTranslationFile,
    'inputPassportElementErrorSourceTranslationFiles': InputPassportElementErrorSourceTranslationFiles,
    'inputPassportElementErrorSourceUnspecified': InputPassportElementErrorSourceUnspecified,
    'inputPersonalDocument': InputPersonalDocument,
    'inputSticker': InputSticker,
    'inputStickerAnimated': InputStickerAnimated,
    'inputStickerStatic': InputStickerStatic,
    'inputThumbnail': InputThumbnail,
    'invoice': Invoice,
    'jsonValue': JsonValue,
    'jsonValueArray': JsonValueArray,
    'jsonValueBoolean': JsonValueBoolean,
    'jsonValueNull': JsonValueNull,
    'jsonValueNumber': JsonValueNumber,
    'jsonValueObject': JsonValueObject,
    'jsonValueString': JsonValueString,
    'keyboardButton': KeyboardButton,
    'keyboardButtonType': KeyboardButtonType,
    'keyboardButtonTypeRequestLocation': KeyboardButtonTypeRequestLocation,
    'keyboardButtonTypeRequestPhoneNumber': KeyboardButtonTypeRequestPhoneNumber,
    'keyboardButtonTypeRequestPoll': KeyboardButtonTypeRequestPoll,
    'keyboardButtonTypeText': KeyboardButtonTypeText,
    'labeledPricePart': LabeledPricePart,
    'languagePackInfo': LanguagePackInfo,
    'languagePackString': LanguagePackString,
    'languagePackStringValue': LanguagePackStringValue,
    'languagePackStringValueDeleted': LanguagePackStringValueDeleted,
    'languagePackStringValueOrdinary': LanguagePackStringValueOrdinary,
    'languagePackStringValuePluralized': LanguagePackStringValuePluralized,
    'languagePackStrings': LanguagePackStrings,
    'localFile': LocalFile,
    'localizationTargetInfo': LocalizationTargetInfo,
    'location': Location,
    'logStream': LogStream,
    'logStreamDefault': LogStreamDefault,
    'logStreamEmpty': LogStreamEmpty,
    'logStreamFile': LogStreamFile,
    'logTags': LogTags,
    'logVerbosityLevel': LogVerbosityLevel,
    'loginUrlInfo': LoginUrlInfo,
    'loginUrlInfoOpen': LoginUrlInfoOpen,
    'loginUrlInfoRequestConfirmation': LoginUrlInfoRequestConfirmation,
    'maskPoint': MaskPoint,
    'maskPointChin': MaskPointChin,
    'maskPointEyes': MaskPointEyes,
    'maskPointForehead': MaskPointForehead,
    'maskPointMouth': MaskPointMouth,
    'maskPosition': MaskPosition,
    'message': Message,
    'messageContent': MessageContent,
    'messageAnimation': MessageAnimation,
    'messageAudio': MessageAudio,
    'messageBasicGroupChatCreate': MessageBasicGroupChatCreate,
    'messageCall': MessageCall,
    'messageChatAddMembers': MessageChatAddMembers,
    'messageChatChangePhoto': MessageChatChangePhoto,
    'messageChatChangeTitle': MessageChatChangeTitle,
    'messageChatDeleteMember': MessageChatDeleteMember,
    'messageChatDeletePhoto': MessageChatDeletePhoto,
    'messageChatJoinByLink': MessageChatJoinByLink,
    'messageChatSetTtl': MessageChatSetTtl,
    'messageChatUpgradeFrom': MessageChatUpgradeFrom,
    'messageChatUpgradeTo': MessageChatUpgradeTo,
    'messageContact': MessageContact,
    'messageContactRegistered': MessageContactRegistered,
    'messageCustomServiceAction': MessageCustomServiceAction,
    'messageDice': MessageDice,
    'messageDocument': MessageDocument,
    'messageExpiredPhoto': MessageExpiredPhoto,
    'messageExpiredVideo': MessageExpiredVideo,
    'messageGame': MessageGame,
    'messageGameScore': MessageGameScore,
    'messageInviteVoiceChatParticipants': MessageInviteVoiceChatParticipants,
    'messageInvoice': MessageInvoice,
    'messageLocation': MessageLocation,
    'messagePassportDataReceived': MessagePassportDataReceived,
    'messagePassportDataSent': MessagePassportDataSent,
    'messagePaymentSuccessful': MessagePaymentSuccessful,
    'messagePaymentSuccessfulBot': MessagePaymentSuccessfulBot,
    'messagePhoto': MessagePhoto,
    'messagePinMessage': MessagePinMessage,
    'messagePoll': MessagePoll,
    'messageProximityAlertTriggered': MessageProximityAlertTriggered,
    'messageScreenshotTaken': MessageScreenshotTaken,
    'messageSticker': MessageSticker,
    'messageSupergroupChatCreate': MessageSupergroupChatCreate,
    'messageText': MessageText,
    'messageUnsupported': MessageUnsupported,
    'messageVenue': MessageVenue,
    'messageVideo': MessageVideo,
    'messageVideoNote': MessageVideoNote,
    'messageVoiceChatEnded': MessageVoiceChatEnded,
    'messageVoiceChatStarted': MessageVoiceChatStarted,
    'messageVoiceNote': MessageVoiceNote,
    'messageWebsiteConnected': MessageWebsiteConnected,
    'messageCopyOptions': MessageCopyOptions,
    'messageFileType': MessageFileType,
    'messageFileTypeGroup': MessageFileTypeGroup,
    'messageFileTypePrivate': MessageFileTypePrivate,
    'messageFileTypeUnknown': MessageFileTypeUnknown,
    'messageForwardInfo': MessageForwardInfo,
    'messageForwardOrigin': MessageForwardOrigin,
    'messageForwardOriginChannel': MessageForwardOriginChannel,
    'messageForwardOriginChat': MessageForwardOriginChat,
    'messageForwardOriginHiddenUser': MessageForwardOriginHiddenUser,
    'messageForwardOriginMessageImport': MessageForwardOriginMessageImport,
    'messageForwardOriginUser': MessageForwardOriginUser,
    'messageInteractionInfo': MessageInteractionInfo,
    'messageLink': MessageLink,
    'messageLinkInfo': MessageLinkInfo,
    'messageReplyInfo': MessageReplyInfo,
    'messageSchedulingState': MessageSchedulingState,
    'messageSchedulingStateSendAtDate': MessageSchedulingStateSendAtDate,
    'messageSchedulingStateSendWhenOnline': MessageSchedulingStateSendWhenOnline,
    'messageSendOptions': MessageSendOptions,
    'messageSender': MessageSender,
    'messageSenderChat': MessageSenderChat,
    'messageSenderUser': MessageSenderUser,
    'messageSenders': MessageSenders,
    'messageSendingState': MessageSendingState,
    'messageSendingStateFailed': MessageSendingStateFailed,
    'messageSendingStatePending': MessageSendingStatePending,
    'messageStatistics': MessageStatistics,
    'messageThreadInfo': MessageThreadInfo,
    'messages': Messages,
    'minithumbnail': Minithumbnail,
    'networkStatistics': NetworkStatistics,
    'networkStatisticsEntry': NetworkStatisticsEntry,
    'networkStatisticsEntryCall': NetworkStatisticsEntryCall,
    'networkStatisticsEntryFile': NetworkStatisticsEntryFile,
    'networkType': NetworkType,
    'networkTypeMobile': NetworkTypeMobile,
    'networkTypeMobileRoaming': NetworkTypeMobileRoaming,
    'networkTypeNone': NetworkTypeNone,
    'networkTypeOther': NetworkTypeOther,
    'networkTypeWiFi': NetworkTypeWiFi,
    'notification': Notification,
    'notificationGroup': NotificationGroup,
    'notificationGroupType': NotificationGroupType,
    'notificationGroupTypeCalls': NotificationGroupTypeCalls,
    'notificationGroupTypeMentions': NotificationGroupTypeMentions,
    'notificationGroupTypeMessages': NotificationGroupTypeMessages,
    'notificationGroupTypeSecretChat': NotificationGroupTypeSecretChat,
    'notificationSettingsScope': NotificationSettingsScope,
    'notificationSettingsScopeChannelChats': NotificationSettingsScopeChannelChats,
    'notificationSettingsScopeGroupChats': NotificationSettingsScopeGroupChats,
    'notificationSettingsScopePrivateChats': NotificationSettingsScopePrivateChats,
    'notificationType': NotificationType,
    'notificationTypeNewCall': NotificationTypeNewCall,
    'notificationTypeNewMessage': NotificationTypeNewMessage,
    'notificationTypeNewPushMessage': NotificationTypeNewPushMessage,
    'notificationTypeNewSecretChat': NotificationTypeNewSecretChat,
    'ok': Ok,
    'optionValue': OptionValue,
    'optionValueBoolean': OptionValueBoolean,
    'optionValueEmpty': OptionValueEmpty,
    'optionValueInteger': OptionValueInteger,
    'optionValueString': OptionValueString,
    'orderInfo': OrderInfo,
    'pageBlock': PageBlock,
    'pageBlockAnchor': PageBlockAnchor,
    'pageBlockAnimation': PageBlockAnimation,
    'pageBlockAudio': PageBlockAudio,
    'pageBlockAuthorDate': PageBlockAuthorDate,
    'pageBlockBlockQuote': PageBlockBlockQuote,
    'pageBlockChatLink': PageBlockChatLink,
    'pageBlockCollage': PageBlockCollage,
    'pageBlockCover': PageBlockCover,
    'pageBlockDetails': PageBlockDetails,
    'pageBlockDivider': PageBlockDivider,
    'pageBlockEmbedded': PageBlockEmbedded,
    'pageBlockEmbeddedPost': PageBlockEmbeddedPost,
    'pageBlockFooter': PageBlockFooter,
    'pageBlockHeader': PageBlockHeader,
    'pageBlockKicker': PageBlockKicker,
    'pageBlockList': PageBlockList,
    'pageBlockMap': PageBlockMap,
    'pageBlockParagraph': PageBlockParagraph,
    'pageBlockPhoto': PageBlockPhoto,
    'pageBlockPreformatted': PageBlockPreformatted,
    'pageBlockPullQuote': PageBlockPullQuote,
    'pageBlockRelatedArticles': PageBlockRelatedArticles,
    'pageBlockSlideshow': PageBlockSlideshow,
    'pageBlockSubheader': PageBlockSubheader,
    'pageBlockSubtitle': PageBlockSubtitle,
    'pageBlockTable': PageBlockTable,
    'pageBlockTitle': PageBlockTitle,
    'pageBlockVideo': PageBlockVideo,
    'pageBlockVoiceNote': PageBlockVoiceNote,
    'pageBlockCaption': PageBlockCaption,
    'pageBlockHorizontalAlignment': PageBlockHorizontalAlignment,
    'pageBlockHorizontalAlignmentCenter': PageBlockHorizontalAlignmentCenter,
    'pageBlockHorizontalAlignmentLeft': PageBlockHorizontalAlignmentLeft,
    'pageBlockHorizontalAlignmentRight': PageBlockHorizontalAlignmentRight,
    'pageBlockRelatedArticle': PageBlockRelatedArticle,
    'pageBlockTableCell': PageBlockTableCell,
    'pageBlockVerticalAlignment': PageBlockVerticalAlignment,
    'pageBlockVerticalAlignmentBottom': PageBlockVerticalAlignmentBottom,
    'pageBlockVerticalAlignmentMiddle': PageBlockVerticalAlignmentMiddle,
    'pageBlockVerticalAlignmentTop': PageBlockVerticalAlignmentTop,
    'passportAuthorizationForm': PassportAuthorizationForm,
    'passportElement': PassportElement,
    'passportElementAddress': PassportElementAddress,
    'passportElementBankStatement': PassportElementBankStatement,
    'passportElementDriverLicense': PassportElementDriverLicense,
    'passportElementEmailAddress': PassportElementEmailAddress,
    'passportElementIdentityCard': PassportElementIdentityCard,
    'passportElementInternalPassport': PassportElementInternalPassport,
    'passportElementPassport': PassportElementPassport,
    'passportElementPassportRegistration': PassportElementPassportRegistration,
    'passportElementPersonalDetails': PassportElementPersonalDetails,
    'passportElementPhoneNumber': PassportElementPhoneNumber,
    'passportElementRentalAgreement': PassportElementRentalAgreement,
    'passportElementTemporaryRegistration': PassportElementTemporaryRegistration,
    'passportElementUtilityBill': PassportElementUtilityBill,
    'passportElementError': PassportElementError,
    'passportElementErrorSource': PassportElementErrorSource,
    'passportElementErrorSourceDataField': PassportElementErrorSourceDataField,
    'passportElementErrorSourceFile': PassportElementErrorSourceFile,
    'passportElementErrorSourceFiles': PassportElementErrorSourceFiles,
    'passportElementErrorSourceFrontSide': PassportElementErrorSourceFrontSide,
    'passportElementErrorSourceReverseSide': PassportElementErrorSourceReverseSide,
    'passportElementErrorSourceSelfie': PassportElementErrorSourceSelfie,
    'passportElementErrorSourceTranslationFile': PassportElementErrorSourceTranslationFile,
    'passportElementErrorSourceTranslationFiles': PassportElementErrorSourceTranslationFiles,
    'passportElementErrorSourceUnspecified': PassportElementErrorSourceUnspecified,
    'passportElementType': PassportElementType,
    'passportElementTypeAddress': PassportElementTypeAddress,
    'passportElementTypeBankStatement': PassportElementTypeBankStatement,
    'passportElementTypeDriverLicense': PassportElementTypeDriverLicense,
    'passportElementTypeEmailAddress': PassportElementTypeEmailAddress,
    'passportElementTypeIdentityCard': PassportElementTypeIdentityCard,
    'passportElementTypeInternalPassport': PassportElementTypeInternalPassport,
    'passportElementTypePassport': PassportElementTypePassport,
    'passportElementTypePassportRegistration': PassportElementTypePassportRegistration,
    'passportElementTypePersonalDetails': PassportElementTypePersonalDetails,
    'passportElementTypePhoneNumber': PassportElementTypePhoneNumber,
    'passportElementTypeRentalAgreement': PassportElementTypeRentalAgreement,
    'passportElementTypeTemporaryRegistration': PassportElementTypeTemporaryRegistration,
    'passportElementTypeUtilityBill': PassportElementTypeUtilityBill,
    'passportElements': PassportElements,
    'passportElementsWithErrors': PassportElementsWithErrors,
    'passportRequiredElement': PassportRequiredElement,
    'passportSuitableElement': PassportSuitableElement,
    'passwordState': PasswordState,
    'paymentForm': PaymentForm,
    'paymentReceipt': PaymentReceipt,
    'paymentResult': PaymentResult,
    'paymentsProviderStripe': PaymentsProviderStripe,
    'personalDetails': PersonalDetails,
    'personalDocument': PersonalDocument,
    'phoneNumberAuthenticationSettings': PhoneNumberAuthenticationSettings,
    'phoneNumberInfo': PhoneNumberInfo,
    'photo': Photo,
    'photoSize': PhotoSize,
    'point': Point,
    'poll': Poll,
    'pollOption': PollOption,
    'pollType': PollType,
    'pollTypeQuiz': PollTypeQuiz,
    'pollTypeRegular': PollTypeRegular,
    'profilePhoto': ProfilePhoto,
    'proxies': Proxies,
    'proxy': Proxy,
    'proxyType': ProxyType,
    'proxyTypeHttp': ProxyTypeHttp,
    'proxyTypeMtproto': ProxyTypeMtproto,
    'proxyTypeSocks5': ProxyTypeSocks5,
    'publicChatType': PublicChatType,
    'publicChatTypeHasUsername': PublicChatTypeHasUsername,
    'publicChatTypeIsLocationBased': PublicChatTypeIsLocationBased,
    'pushMessageContent': PushMessageContent,
    'pushMessageContentAnimation': PushMessageContentAnimation,
    'pushMessageContentAudio': PushMessageContentAudio,
    'pushMessageContentBasicGroupChatCreate': PushMessageContentBasicGroupChatCreate,
    'pushMessageContentChatAddMembers': PushMessageContentChatAddMembers,
    'pushMessageContentChatChangePhoto': PushMessageContentChatChangePhoto,
    'pushMessageContentChatChangeTitle': PushMessageContentChatChangeTitle,
    'pushMessageContentChatDeleteMember': PushMessageContentChatDeleteMember,
    'pushMessageContentChatJoinByLink': PushMessageContentChatJoinByLink,
    'pushMessageContentContact': PushMessageContentContact,
    'pushMessageContentContactRegistered': PushMessageContentContactRegistered,
    'pushMessageContentDocument': PushMessageContentDocument,
    'pushMessageContentGame': PushMessageContentGame,
    'pushMessageContentGameScore': PushMessageContentGameScore,
    'pushMessageContentHidden': PushMessageContentHidden,
    'pushMessageContentInvoice': PushMessageContentInvoice,
    'pushMessageContentLocation': PushMessageContentLocation,
    'pushMessageContentMediaAlbum': PushMessageContentMediaAlbum,
    'pushMessageContentMessageForwards': PushMessageContentMessageForwards,
    'pushMessageContentPhoto': PushMessageContentPhoto,
    'pushMessageContentPoll': PushMessageContentPoll,
    'pushMessageContentScreenshotTaken': PushMessageContentScreenshotTaken,
    'pushMessageContentSticker': PushMessageContentSticker,
    'pushMessageContentText': PushMessageContentText,
    'pushMessageContentVideo': PushMessageContentVideo,
    'pushMessageContentVideoNote': PushMessageContentVideoNote,
    'pushMessageContentVoiceNote': PushMessageContentVoiceNote,
    'pushReceiverId': PushReceiverId,
    'recommendedChatFilter': RecommendedChatFilter,
    'recommendedChatFilters': RecommendedChatFilters,
    'recoveryEmailAddress': RecoveryEmailAddress,
    'remoteFile': RemoteFile,
    'replyMarkup': ReplyMarkup,
    'replyMarkupForceReply': ReplyMarkupForceReply,
    'replyMarkupInlineKeyboard': ReplyMarkupInlineKeyboard,
    'replyMarkupRemoveKeyboard': ReplyMarkupRemoveKeyboard,
    'replyMarkupShowKeyboard': ReplyMarkupShowKeyboard,
    'richText': RichText,
    'richTextAnchor': RichTextAnchor,
    'richTextAnchorLink': RichTextAnchorLink,
    'richTextBold': RichTextBold,
    'richTextEmailAddress': RichTextEmailAddress,
    'richTextFixed': RichTextFixed,
    'richTextIcon': RichTextIcon,
    'richTextItalic': RichTextItalic,
    'richTextMarked': RichTextMarked,
    'richTextPhoneNumber': RichTextPhoneNumber,
    'richTextPlain': RichTextPlain,
    'richTextReference': RichTextReference,
    'richTextStrikethrough': RichTextStrikethrough,
    'richTextSubscript': RichTextSubscript,
    'richTextSuperscript': RichTextSuperscript,
    'richTextUnderline': RichTextUnderline,
    'richTextUrl': RichTextUrl,
    'richTexts': RichTexts,
    'savedCredentials': SavedCredentials,
    'scopeNotificationSettings': ScopeNotificationSettings,
    'searchMessagesFilter': SearchMessagesFilter,
    'searchMessagesFilterAnimation': SearchMessagesFilterAnimation,
    'searchMessagesFilterAudio': SearchMessagesFilterAudio,
    'searchMessagesFilterCall': SearchMessagesFilterCall,
    'searchMessagesFilterChatPhoto': SearchMessagesFilterChatPhoto,
    'searchMessagesFilterDocument': SearchMessagesFilterDocument,
    'searchMessagesFilterEmpty': SearchMessagesFilterEmpty,
    'searchMessagesFilterFailedToSend': SearchMessagesFilterFailedToSend,
    'searchMessagesFilterMention': SearchMessagesFilterMention,
    'searchMessagesFilterMissedCall': SearchMessagesFilterMissedCall,
    'searchMessagesFilterPhoto': SearchMessagesFilterPhoto,
    'searchMessagesFilterPhotoAndVideo': SearchMessagesFilterPhotoAndVideo,
    'searchMessagesFilterPinned': SearchMessagesFilterPinned,
    'searchMessagesFilterUnreadMention': SearchMessagesFilterUnreadMention,
    'searchMessagesFilterUrl': SearchMessagesFilterUrl,
    'searchMessagesFilterVideo': SearchMessagesFilterVideo,
    'searchMessagesFilterVideoNote': SearchMessagesFilterVideoNote,
    'searchMessagesFilterVoiceAndVideoNote': SearchMessagesFilterVoiceAndVideoNote,
    'searchMessagesFilterVoiceNote': SearchMessagesFilterVoiceNote,
    'seconds': Seconds,
    'secretChat': SecretChat,
    'secretChatState': SecretChatState,
    'secretChatStateClosed': SecretChatStateClosed,
    'secretChatStatePending': SecretChatStatePending,
    'secretChatStateReady': SecretChatStateReady,
    'session': Session,
    'sessions': Sessions,
    'shippingOption': ShippingOption,
    'statisticalGraph': StatisticalGraph,
    'statisticalGraphAsync': StatisticalGraphAsync,
    'statisticalGraphData': StatisticalGraphData,
    'statisticalGraphError': StatisticalGraphError,
    'statisticalValue': StatisticalValue,
    'sticker': Sticker,
    'stickerSet': StickerSet,
    'stickerSetInfo': StickerSetInfo,
    'stickerSets': StickerSets,
    'stickers': Stickers,
    'storageStatistics': StorageStatistics,
    'storageStatisticsByChat': StorageStatisticsByChat,
    'storageStatisticsByFileType': StorageStatisticsByFileType,
    'storageStatisticsFast': StorageStatisticsFast,
    'suggestedAction': SuggestedAction,
    'suggestedActionCheckPhoneNumber': SuggestedActionCheckPhoneNumber,
    'suggestedActionConvertToBroadcastGroup': SuggestedActionConvertToBroadcastGroup,
    'suggestedActionEnableArchiveAndMuteNewChats': SuggestedActionEnableArchiveAndMuteNewChats,
    'suggestedActionSeeTicksHint': SuggestedActionSeeTicksHint,
    'supergroup': Supergroup,
    'supergroupFullInfo': SupergroupFullInfo,
    'supergroupMembersFilter': SupergroupMembersFilter,
    'supergroupMembersFilterAdministrators': SupergroupMembersFilterAdministrators,
    'supergroupMembersFilterBanned': SupergroupMembersFilterBanned,
    'supergroupMembersFilterBots': SupergroupMembersFilterBots,
    'supergroupMembersFilterContacts': SupergroupMembersFilterContacts,
    'supergroupMembersFilterMention': SupergroupMembersFilterMention,
    'supergroupMembersFilterRecent': SupergroupMembersFilterRecent,
    'supergroupMembersFilterRestricted': SupergroupMembersFilterRestricted,
    'supergroupMembersFilterSearch': SupergroupMembersFilterSearch,
    'tMeUrl': TMeUrl,
    'tMeUrlType': TMeUrlType,
    'tMeUrlTypeChatInvite': TMeUrlTypeChatInvite,
    'tMeUrlTypeStickerSet': TMeUrlTypeStickerSet,
    'tMeUrlTypeSupergroup': TMeUrlTypeSupergroup,
    'tMeUrlTypeUser': TMeUrlTypeUser,
    'tMeUrls': TMeUrls,
    'tdlibParameters': TdlibParameters,
    'temporaryPasswordState': TemporaryPasswordState,
    'termsOfService': TermsOfService,
    'testBytes': TestBytes,
    'testInt': TestInt,
    'testString': TestString,
    'testVectorInt': TestVectorInt,
    'testVectorIntObject': TestVectorIntObject,
    'testVectorString': TestVectorString,
    'testVectorStringObject': TestVectorStringObject,
    'text': Text,
    'textEntities': TextEntities,
    'textEntity': TextEntity,
    'textEntityType': TextEntityType,
    'textEntityTypeBankCardNumber': TextEntityTypeBankCardNumber,
    'textEntityTypeBold': TextEntityTypeBold,
    'textEntityTypeBotCommand': TextEntityTypeBotCommand,
    'textEntityTypeCashtag': TextEntityTypeCashtag,
    'textEntityTypeCode': TextEntityTypeCode,
    'textEntityTypeEmailAddress': TextEntityTypeEmailAddress,
    'textEntityTypeHashtag': TextEntityTypeHashtag,
    'textEntityTypeItalic': TextEntityTypeItalic,
    'textEntityTypeMention': TextEntityTypeMention,
    'textEntityTypeMentionName': TextEntityTypeMentionName,
    'textEntityTypePhoneNumber': TextEntityTypePhoneNumber,
    'textEntityTypePre': TextEntityTypePre,
    'textEntityTypePreCode': TextEntityTypePreCode,
    'textEntityTypeStrikethrough': TextEntityTypeStrikethrough,
    'textEntityTypeTextUrl': TextEntityTypeTextUrl,
    'textEntityTypeUnderline': TextEntityTypeUnderline,
    'textEntityTypeUrl': TextEntityTypeUrl,
    'textParseMode': TextParseMode,
    'textParseModeHTML': TextParseModeHTML,
    'textParseModeMarkdown': TextParseModeMarkdown,
    'thumbnail': Thumbnail,
    'thumbnailFormat': ThumbnailFormat,
    'thumbnailFormatGif': ThumbnailFormatGif,
    'thumbnailFormatJpeg': ThumbnailFormatJpeg,
    'thumbnailFormatMpeg4': ThumbnailFormatMpeg4,
    'thumbnailFormatPng': ThumbnailFormatPng,
    'thumbnailFormatTgs': ThumbnailFormatTgs,
    'thumbnailFormatWebp': ThumbnailFormatWebp,
    'topChatCategory': TopChatCategory,
    'topChatCategoryBots': TopChatCategoryBots,
    'topChatCategoryCalls': TopChatCategoryCalls,
    'topChatCategoryChannels': TopChatCategoryChannels,
    'topChatCategoryForwardChats': TopChatCategoryForwardChats,
    'topChatCategoryGroups': TopChatCategoryGroups,
    'topChatCategoryInlineBots': TopChatCategoryInlineBots,
    'topChatCategoryUsers': TopChatCategoryUsers,
    'update': Update,
    'updateActiveNotifications': UpdateActiveNotifications,
    'updateAnimationSearchParameters': UpdateAnimationSearchParameters,
    'updateAuthorizationState': UpdateAuthorizationState,
    'updateBasicGroup': UpdateBasicGroup,
    'updateBasicGroupFullInfo': UpdateBasicGroupFullInfo,
    'updateCall': UpdateCall,
    'updateChatActionBar': UpdateChatActionBar,
    'updateChatDefaultDisableNotification': UpdateChatDefaultDisableNotification,
    'updateChatDraftMessage': UpdateChatDraftMessage,
    'updateChatFilters': UpdateChatFilters,
    'updateChatHasScheduledMessages': UpdateChatHasScheduledMessages,
    'updateChatIsBlocked': UpdateChatIsBlocked,
    'updateChatIsMarkedAsUnread': UpdateChatIsMarkedAsUnread,
    'updateChatLastMessage': UpdateChatLastMessage,
    'updateChatMember': UpdateChatMember,
    'updateChatMessageTtlSetting': UpdateChatMessageTtlSetting,
    'updateChatNotificationSettings': UpdateChatNotificationSettings,
    'updateChatOnlineMemberCount': UpdateChatOnlineMemberCount,
    'updateChatPermissions': UpdateChatPermissions,
    'updateChatPhoto': UpdateChatPhoto,
    'updateChatPosition': UpdateChatPosition,
    'updateChatReadInbox': UpdateChatReadInbox,
    'updateChatReadOutbox': UpdateChatReadOutbox,
    'updateChatReplyMarkup': UpdateChatReplyMarkup,
    'updateChatTitle': UpdateChatTitle,
    'updateChatUnreadMentionCount': UpdateChatUnreadMentionCount,
    'updateChatVoiceChat': UpdateChatVoiceChat,
    'updateConnectionState': UpdateConnectionState,
    'updateDeleteMessages': UpdateDeleteMessages,
    'updateDiceEmojis': UpdateDiceEmojis,
    'updateFavoriteStickers': UpdateFavoriteStickers,
    'updateFile': UpdateFile,
    'updateFileGenerationStart': UpdateFileGenerationStart,
    'updateFileGenerationStop': UpdateFileGenerationStop,
    'updateGroupCall': UpdateGroupCall,
    'updateGroupCallParticipant': UpdateGroupCallParticipant,
    'updateHavePendingNotifications': UpdateHavePendingNotifications,
    'updateInstalledStickerSets': UpdateInstalledStickerSets,
    'updateLanguagePackStrings': UpdateLanguagePackStrings,
    'updateMessageContent': UpdateMessageContent,
    'updateMessageContentOpened': UpdateMessageContentOpened,
    'updateMessageEdited': UpdateMessageEdited,
    'updateMessageInteractionInfo': UpdateMessageInteractionInfo,
    'updateMessageIsPinned': UpdateMessageIsPinned,
    'updateMessageLiveLocationViewed': UpdateMessageLiveLocationViewed,
    'updateMessageMentionRead': UpdateMessageMentionRead,
    'updateMessageSendAcknowledged': UpdateMessageSendAcknowledged,
    'updateMessageSendFailed': UpdateMessageSendFailed,
    'updateMessageSendSucceeded': UpdateMessageSendSucceeded,
    'updateNewCallSignalingData': UpdateNewCallSignalingData,
    'updateNewCallbackQuery': UpdateNewCallbackQuery,
    'updateNewChat': UpdateNewChat,
    'updateNewChosenInlineResult': UpdateNewChosenInlineResult,
    'updateNewCustomEvent': UpdateNewCustomEvent,
    'updateNewCustomQuery': UpdateNewCustomQuery,
    'updateNewInlineCallbackQuery': UpdateNewInlineCallbackQuery,
    'updateNewInlineQuery': UpdateNewInlineQuery,
    'updateNewMessage': UpdateNewMessage,
    'updateNewPreCheckoutQuery': UpdateNewPreCheckoutQuery,
    'updateNewShippingQuery': UpdateNewShippingQuery,
    'updateNotification': UpdateNotification,
    'updateNotificationGroup': UpdateNotificationGroup,
    'updateOption': UpdateOption,
    'updatePoll': UpdatePoll,
    'updatePollAnswer': UpdatePollAnswer,
    'updateRecentStickers': UpdateRecentStickers,
    'updateSavedAnimations': UpdateSavedAnimations,
    'updateScopeNotificationSettings': UpdateScopeNotificationSettings,
    'updateSecretChat': UpdateSecretChat,
    'updateSelectedBackground': UpdateSelectedBackground,
    'updateServiceNotification': UpdateServiceNotification,
    'updateStickerSet': UpdateStickerSet,
    'updateSuggestedActions': UpdateSuggestedActions,
    'updateSupergroup': UpdateSupergroup,
    'updateSupergroupFullInfo': UpdateSupergroupFullInfo,
    'updateTermsOfService': UpdateTermsOfService,
    'updateTrendingStickerSets': UpdateTrendingStickerSets,
    'updateUnreadChatCount': UpdateUnreadChatCount,
    'updateUnreadMessageCount': UpdateUnreadMessageCount,
    'updateUser': UpdateUser,
    'updateUserChatAction': UpdateUserChatAction,
    'updateUserFullInfo': UpdateUserFullInfo,
    'updateUserPrivacySettingRules': UpdateUserPrivacySettingRules,
    'updateUserStatus': UpdateUserStatus,
    'updateUsersNearby': UpdateUsersNearby,
    'updates': Updates,
    'user': User,
    'userFullInfo': UserFullInfo,
    'userPrivacySetting': UserPrivacySetting,
    'userPrivacySettingAllowCalls': UserPrivacySettingAllowCalls,
    'userPrivacySettingAllowChatInvites': UserPrivacySettingAllowChatInvites,
    'userPrivacySettingAllowFindingByPhoneNumber': UserPrivacySettingAllowFindingByPhoneNumber,
    'userPrivacySettingAllowPeerToPeerCalls': UserPrivacySettingAllowPeerToPeerCalls,
    'userPrivacySettingShowLinkInForwardedMessages': UserPrivacySettingShowLinkInForwardedMessages,
    'userPrivacySettingShowPhoneNumber': UserPrivacySettingShowPhoneNumber,
    'userPrivacySettingShowProfilePhoto': UserPrivacySettingShowProfilePhoto,
    'userPrivacySettingShowStatus': UserPrivacySettingShowStatus,
    'userPrivacySettingRule': UserPrivacySettingRule,
    'userPrivacySettingRuleAllowAll': UserPrivacySettingRuleAllowAll,
    'userPrivacySettingRuleAllowChatMembers': UserPrivacySettingRuleAllowChatMembers,
    'userPrivacySettingRuleAllowContacts': UserPrivacySettingRuleAllowContacts,
    'userPrivacySettingRuleAllowUsers': UserPrivacySettingRuleAllowUsers,
    'userPrivacySettingRuleRestrictAll': UserPrivacySettingRuleRestrictAll,
    'userPrivacySettingRuleRestrictChatMembers': UserPrivacySettingRuleRestrictChatMembers,
    'userPrivacySettingRuleRestrictContacts': UserPrivacySettingRuleRestrictContacts,
    'userPrivacySettingRuleRestrictUsers': UserPrivacySettingRuleRestrictUsers,
    'userPrivacySettingRules': UserPrivacySettingRules,
    'userStatus': UserStatus,
    'userStatusEmpty': UserStatusEmpty,
    'userStatusLastMonth': UserStatusLastMonth,
    'userStatusLastWeek': UserStatusLastWeek,
    'userStatusOffline': UserStatusOffline,
    'userStatusOnline': UserStatusOnline,
    'userStatusRecently': UserStatusRecently,
    'userType': UserType,
    'userTypeBot': UserTypeBot,
    'userTypeDeleted': UserTypeDeleted,
    'userTypeRegular': UserTypeRegular,
    'userTypeUnknown': UserTypeUnknown,
    'users': Users,
    'validatedOrderInfo': ValidatedOrderInfo,
    'vectorPathCommand': VectorPathCommand,
    'vectorPathCommandCubicBezierCurve': VectorPathCommandCubicBezierCurve,
    'vectorPathCommandLine': VectorPathCommandLine,
    'venue': Venue,
    'video': Video,
    'videoNote': VideoNote,
    'voiceChat': VoiceChat,
    'voiceNote': VoiceNote,
    'webPage': WebPage,
    'webPageInstantView': WebPageInstantView,
}

__all__ = [
    'AioTDLibError',
    'API',
    'BaseObject',

    # Types and Functions
    'AcceptCall',
    'AcceptTermsOfService',
    'AccountTtl',
    'AddChatMember',
    'AddChatMembers',
    'AddChatToList',
    'AddContact',
    'AddCustomServerLanguagePack',
    'AddFavoriteSticker',
    'AddLocalMessage',
    'AddLogMessage',
    'AddNetworkStatistics',
    'AddProxy',
    'AddRecentSticker',
    'AddRecentlyFoundChat',
    'AddSavedAnimation',
    'AddStickerToSet',
    'Address',
    'AnimatedChatPhoto',
    'Animation',
    'Animations',
    'AnswerCallbackQuery',
    'AnswerCustomQuery',
    'AnswerInlineQuery',
    'AnswerPreCheckoutQuery',
    'AnswerShippingQuery',
    'Audio',
    'AuthenticationCodeInfo',
    'AuthenticationCodeType',
    'AuthenticationCodeTypeCall',
    'AuthenticationCodeTypeFlashCall',
    'AuthenticationCodeTypeSms',
    'AuthenticationCodeTypeTelegramMessage',
    'AuthorizationState',
    'AuthorizationStateClosed',
    'AuthorizationStateClosing',
    'AuthorizationStateLoggingOut',
    'AuthorizationStateReady',
    'AuthorizationStateWaitCode',
    'AuthorizationStateWaitEncryptionKey',
    'AuthorizationStateWaitOtherDeviceConfirmation',
    'AuthorizationStateWaitPassword',
    'AuthorizationStateWaitPhoneNumber',
    'AuthorizationStateWaitRegistration',
    'AuthorizationStateWaitTdlibParameters',
    'AutoDownloadSettings',
    'AutoDownloadSettingsPresets',
    'Background',
    'BackgroundFill',
    'BackgroundFillGradient',
    'BackgroundFillSolid',
    'BackgroundType',
    'BackgroundTypeFill',
    'BackgroundTypePattern',
    'BackgroundTypeWallpaper',
    'Backgrounds',
    'BanChatMember',
    'BankCardActionOpenUrl',
    'BankCardInfo',
    'BasicGroup',
    'BasicGroupFullInfo',
    'BlockMessageSenderFromReplies',
    'BotCommand',
    'BotInfo',
    'Call',
    'CallDiscardReason',
    'CallDiscardReasonDeclined',
    'CallDiscardReasonDisconnected',
    'CallDiscardReasonEmpty',
    'CallDiscardReasonHungUp',
    'CallDiscardReasonMissed',
    'CallId',
    'CallProblem',
    'CallProblemDistortedSpeech',
    'CallProblemDistortedVideo',
    'CallProblemDropped',
    'CallProblemEcho',
    'CallProblemInterruptions',
    'CallProblemNoise',
    'CallProblemPixelatedVideo',
    'CallProblemSilentLocal',
    'CallProblemSilentRemote',
    'CallProtocol',
    'CallServer',
    'CallServerType',
    'CallServerTypeTelegramReflector',
    'CallServerTypeWebrtc',
    'CallState',
    'CallStateDiscarded',
    'CallStateError',
    'CallStateExchangingKeys',
    'CallStateHangingUp',
    'CallStatePending',
    'CallStateReady',
    'CallbackQueryAnswer',
    'CallbackQueryPayload',
    'CallbackQueryPayloadData',
    'CallbackQueryPayloadDataWithPassword',
    'CallbackQueryPayloadGame',
    'CanTransferOwnership',
    'CanTransferOwnershipResult',
    'CanTransferOwnershipResultOk',
    'CanTransferOwnershipResultPasswordNeeded',
    'CanTransferOwnershipResultPasswordTooFresh',
    'CanTransferOwnershipResultSessionTooFresh',
    'CancelDownloadFile',
    'CancelUploadFile',
    'ChangeImportedContacts',
    'ChangePhoneNumber',
    'ChangeStickerSet',
    'Chat',
    'ChatAction',
    'ChatActionCancel',
    'ChatActionChoosingContact',
    'ChatActionChoosingLocation',
    'ChatActionRecordingVideo',
    'ChatActionRecordingVideoNote',
    'ChatActionRecordingVoiceNote',
    'ChatActionStartPlayingGame',
    'ChatActionTyping',
    'ChatActionUploadingDocument',
    'ChatActionUploadingPhoto',
    'ChatActionUploadingVideo',
    'ChatActionUploadingVideoNote',
    'ChatActionUploadingVoiceNote',
    'ChatActionBar',
    'ChatActionBarAddContact',
    'ChatActionBarInviteMembers',
    'ChatActionBarReportAddBlock',
    'ChatActionBarReportSpam',
    'ChatActionBarReportUnrelatedLocation',
    'ChatActionBarSharePhoneNumber',
    'ChatAdministrator',
    'ChatAdministrators',
    'ChatEvent',
    'ChatEventAction',
    'ChatEventDescriptionChanged',
    'ChatEventInviteLinkDeleted',
    'ChatEventInviteLinkEdited',
    'ChatEventInviteLinkRevoked',
    'ChatEventInvitesToggled',
    'ChatEventIsAllHistoryAvailableToggled',
    'ChatEventLinkedChatChanged',
    'ChatEventLocationChanged',
    'ChatEventMemberInvited',
    'ChatEventMemberJoined',
    'ChatEventMemberJoinedByInviteLink',
    'ChatEventMemberLeft',
    'ChatEventMemberPromoted',
    'ChatEventMemberRestricted',
    'ChatEventMessageDeleted',
    'ChatEventMessageEdited',
    'ChatEventMessagePinned',
    'ChatEventMessageTtlSettingChanged',
    'ChatEventMessageUnpinned',
    'ChatEventPermissionsChanged',
    'ChatEventPhotoChanged',
    'ChatEventPollStopped',
    'ChatEventSignMessagesToggled',
    'ChatEventSlowModeDelayChanged',
    'ChatEventStickerSetChanged',
    'ChatEventTitleChanged',
    'ChatEventUsernameChanged',
    'ChatEventVoiceChatCreated',
    'ChatEventVoiceChatDiscarded',
    'ChatEventVoiceChatMuteNewParticipantsToggled',
    'ChatEventVoiceChatParticipantIsMutedToggled',
    'ChatEventVoiceChatParticipantVolumeLevelChanged',
    'ChatEventLogFilters',
    'ChatEvents',
    'ChatFilter',
    'ChatFilterInfo',
    'ChatInviteLink',
    'ChatInviteLinkCount',
    'ChatInviteLinkCounts',
    'ChatInviteLinkInfo',
    'ChatInviteLinkMember',
    'ChatInviteLinkMembers',
    'ChatInviteLinks',
    'ChatList',
    'ChatListArchive',
    'ChatListFilter',
    'ChatListMain',
    'ChatLists',
    'ChatLocation',
    'ChatMember',
    'ChatMemberStatus',
    'ChatMemberStatusAdministrator',
    'ChatMemberStatusBanned',
    'ChatMemberStatusCreator',
    'ChatMemberStatusLeft',
    'ChatMemberStatusMember',
    'ChatMemberStatusRestricted',
    'ChatMembers',
    'ChatMembersFilter',
    'ChatMembersFilterAdministrators',
    'ChatMembersFilterBanned',
    'ChatMembersFilterBots',
    'ChatMembersFilterContacts',
    'ChatMembersFilterMembers',
    'ChatMembersFilterMention',
    'ChatMembersFilterRestricted',
    'ChatNearby',
    'ChatNotificationSettings',
    'ChatPermissions',
    'ChatPhoto',
    'ChatPhotoInfo',
    'ChatPhotos',
    'ChatPosition',
    'ChatReportReason',
    'ChatReportReasonChildAbuse',
    'ChatReportReasonCopyright',
    'ChatReportReasonCustom',
    'ChatReportReasonFake',
    'ChatReportReasonPornography',
    'ChatReportReasonSpam',
    'ChatReportReasonUnrelatedLocation',
    'ChatReportReasonViolence',
    'ChatSource',
    'ChatSourceMtprotoProxy',
    'ChatSourcePublicServiceAnnouncement',
    'ChatStatistics',
    'ChatStatisticsChannel',
    'ChatStatisticsSupergroup',
    'ChatStatisticsAdministratorActionsInfo',
    'ChatStatisticsInviterInfo',
    'ChatStatisticsMessageInteractionInfo',
    'ChatStatisticsMessageSenderInfo',
    'ChatType',
    'ChatTypeBasicGroup',
    'ChatTypePrivate',
    'ChatTypeSecret',
    'ChatTypeSupergroup',
    'Chats',
    'ChatsNearby',
    'CheckAuthenticationBotToken',
    'CheckAuthenticationCode',
    'CheckAuthenticationPassword',
    'CheckChangePhoneNumberCode',
    'CheckChatInviteLink',
    'CheckChatUsername',
    'CheckChatUsernameResult',
    'CheckChatUsernameResultOk',
    'CheckChatUsernameResultPublicChatsTooMuch',
    'CheckChatUsernameResultPublicGroupsUnavailable',
    'CheckChatUsernameResultUsernameInvalid',
    'CheckChatUsernameResultUsernameOccupied',
    'CheckCreatedPublicChatsLimit',
    'CheckDatabaseEncryptionKey',
    'CheckEmailAddressVerificationCode',
    'CheckPhoneNumberConfirmationCode',
    'CheckPhoneNumberVerificationCode',
    'CheckRecoveryEmailAddressCode',
    'CleanFileName',
    'ClearAllDraftMessages',
    'ClearImportedContacts',
    'ClearRecentStickers',
    'ClearRecentlyFoundChats',
    'Close',
    'CloseChat',
    'CloseSecretChat',
    'ClosedVectorPath',
    'ConfirmQrCodeAuthentication',
    'ConnectedWebsite',
    'ConnectedWebsites',
    'ConnectionState',
    'ConnectionStateConnecting',
    'ConnectionStateConnectingToProxy',
    'ConnectionStateReady',
    'ConnectionStateUpdating',
    'ConnectionStateWaitingForNetwork',
    'Contact',
    'Count',
    'Countries',
    'CountryInfo',
    'CreateBasicGroupChat',
    'CreateCall',
    'CreateChatFilter',
    'CreateChatInviteLink',
    'CreateNewBasicGroupChat',
    'CreateNewSecretChat',
    'CreateNewStickerSet',
    'CreateNewSupergroupChat',
    'CreatePrivateChat',
    'CreateSecretChat',
    'CreateSupergroupChat',
    'CreateTemporaryPassword',
    'CreateVoiceChat',
    'CustomRequestResult',
    'DatabaseStatistics',
    'Date',
    'DateRange',
    'DatedFile',
    'DeepLinkInfo',
    'DeleteAccount',
    'DeleteAllCallMessages',
    'DeleteAllRevokedChatInviteLinks',
    'DeleteChat',
    'DeleteChatFilter',
    'DeleteChatHistory',
    'DeleteChatMessagesFromUser',
    'DeleteChatReplyMarkup',
    'DeleteFile',
    'DeleteLanguagePack',
    'DeleteMessages',
    'DeletePassportElement',
    'DeleteProfilePhoto',
    'DeleteRevokedChatInviteLink',
    'DeleteSavedCredentials',
    'DeleteSavedOrderInfo',
    'Destroy',
    'DeviceToken',
    'DeviceTokenApplePush',
    'DeviceTokenApplePushVoIP',
    'DeviceTokenBlackBerryPush',
    'DeviceTokenFirebaseCloudMessaging',
    'DeviceTokenMicrosoftPush',
    'DeviceTokenMicrosoftPushVoIP',
    'DeviceTokenSimplePush',
    'DeviceTokenTizenPush',
    'DeviceTokenUbuntuPush',
    'DeviceTokenWebPush',
    'DeviceTokenWindowsPush',
    'DiceStickers',
    'DiceStickersRegular',
    'DiceStickersSlotMachine',
    'DisableProxy',
    'DiscardCall',
    'DiscardGroupCall',
    'DisconnectAllWebsites',
    'DisconnectWebsite',
    'Document',
    'DownloadFile',
    'DraftMessage',
    'EditChatFilter',
    'EditChatInviteLink',
    'EditCustomLanguagePackInfo',
    'EditInlineMessageCaption',
    'EditInlineMessageLiveLocation',
    'EditInlineMessageMedia',
    'EditInlineMessageReplyMarkup',
    'EditInlineMessageText',
    'EditMessageCaption',
    'EditMessageLiveLocation',
    'EditMessageMedia',
    'EditMessageReplyMarkup',
    'EditMessageSchedulingState',
    'EditMessageText',
    'EditProxy',
    'EmailAddressAuthenticationCodeInfo',
    'Emojis',
    'EnableProxy',
    'EncryptedCredentials',
    'EncryptedPassportElement',
    'EndGroupCallRecording',
    'Error',
    'File',
    'FilePart',
    'FileType',
    'FileTypeAnimation',
    'FileTypeAudio',
    'FileTypeDocument',
    'FileTypeNone',
    'FileTypePhoto',
    'FileTypeProfilePhoto',
    'FileTypeSecret',
    'FileTypeSecretThumbnail',
    'FileTypeSecure',
    'FileTypeSticker',
    'FileTypeThumbnail',
    'FileTypeUnknown',
    'FileTypeVideo',
    'FileTypeVideoNote',
    'FileTypeVoiceNote',
    'FileTypeWallpaper',
    'FinishFileGeneration',
    'FormattedText',
    'ForwardMessages',
    'FoundMessages',
    'Game',
    'GameHighScore',
    'GameHighScores',
    'GetAccountTtl',
    'GetActiveLiveLocationMessages',
    'GetActiveSessions',
    'GetAllPassportElements',
    'GetApplicationConfig',
    'GetArchivedStickerSets',
    'GetAttachedStickerSets',
    'GetAuthorizationState',
    'GetAutoDownloadSettingsPresets',
    'GetAvailableVoiceChatAliases',
    'GetBackgroundUrl',
    'GetBackgrounds',
    'GetBankCardInfo',
    'GetBasicGroup',
    'GetBasicGroupFullInfo',
    'GetBlockedMessageSenders',
    'GetCallbackQueryAnswer',
    'GetCallbackQueryMessage',
    'GetChat',
    'GetChatAdministrators',
    'GetChatEventLog',
    'GetChatFilter',
    'GetChatFilterDefaultIconName',
    'GetChatHistory',
    'GetChatInviteLink',
    'GetChatInviteLinkCounts',
    'GetChatInviteLinkMembers',
    'GetChatInviteLinks',
    'GetChatListsToAddChat',
    'GetChatMember',
    'GetChatMessageByDate',
    'GetChatMessageCount',
    'GetChatNotificationSettingsExceptions',
    'GetChatPinnedMessage',
    'GetChatScheduledMessages',
    'GetChatStatistics',
    'GetChatStatisticsUrl',
    'GetChats',
    'GetConnectedWebsites',
    'GetContacts',
    'GetCountries',
    'GetCountryCode',
    'GetCreatedPublicChats',
    'GetCurrentState',
    'GetDatabaseStatistics',
    'GetDeepLinkInfo',
    'GetEmojiSuggestionsUrl',
    'GetExternalLink',
    'GetExternalLinkInfo',
    'GetFavoriteStickers',
    'GetFile',
    'GetFileDownloadedPrefixSize',
    'GetFileExtension',
    'GetFileMimeType',
    'GetGameHighScores',
    'GetGroupCall',
    'GetGroupCallInviteLink',
    'GetGroupCallStreamSegment',
    'GetGroupsInCommon',
    'GetImportedContactCount',
    'GetInactiveSupergroupChats',
    'GetInlineGameHighScores',
    'GetInlineQueryResults',
    'GetInstalledStickerSets',
    'GetInviteText',
    'GetJsonString',
    'GetJsonValue',
    'GetLanguagePackInfo',
    'GetLanguagePackString',
    'GetLanguagePackStrings',
    'GetLocalizationTargetInfo',
    'GetLogStream',
    'GetLogTagVerbosityLevel',
    'GetLogTags',
    'GetLogVerbosityLevel',
    'GetLoginUrl',
    'GetLoginUrlInfo',
    'GetMapThumbnailFile',
    'GetMarkdownText',
    'GetMe',
    'GetMessage',
    'GetMessageEmbeddingCode',
    'GetMessageFileType',
    'GetMessageImportConfirmationText',
    'GetMessageLink',
    'GetMessageLinkInfo',
    'GetMessageLocally',
    'GetMessagePublicForwards',
    'GetMessageStatistics',
    'GetMessageThread',
    'GetMessageThreadHistory',
    'GetMessages',
    'GetNetworkStatistics',
    'GetOption',
    'GetPassportAuthorizationForm',
    'GetPassportAuthorizationFormAvailableElements',
    'GetPassportElement',
    'GetPasswordState',
    'GetPaymentForm',
    'GetPaymentReceipt',
    'GetPhoneNumberInfo',
    'GetPollVoters',
    'GetPreferredCountryLanguage',
    'GetProxies',
    'GetProxyLink',
    'GetPushReceiverId',
    'GetRecentInlineBots',
    'GetRecentStickers',
    'GetRecentlyVisitedTMeUrls',
    'GetRecommendedChatFilters',
    'GetRecoveryEmailAddress',
    'GetRemoteFile',
    'GetRepliedMessage',
    'GetSavedAnimations',
    'GetSavedOrderInfo',
    'GetScopeNotificationSettings',
    'GetSecretChat',
    'GetStatisticalGraph',
    'GetStickerEmojis',
    'GetStickerSet',
    'GetStickers',
    'GetStorageStatistics',
    'GetStorageStatisticsFast',
    'GetSuitableDiscussionChats',
    'GetSupergroup',
    'GetSupergroupFullInfo',
    'GetSupergroupMembers',
    'GetSupportUser',
    'GetTemporaryPasswordState',
    'GetTextEntities',
    'GetTopChats',
    'GetTrendingStickerSets',
    'GetUser',
    'GetUserFullInfo',
    'GetUserPrivacySettingRules',
    'GetUserProfilePhotos',
    'GetWebPageInstantView',
    'GetWebPagePreview',
    'GroupCall',
    'GroupCallId',
    'GroupCallJoinResponse',
    'GroupCallJoinResponseStream',
    'GroupCallJoinResponseWebrtc',
    'GroupCallJoinResponseCandidate',
    'GroupCallParticipant',
    'GroupCallPayload',
    'GroupCallPayloadFingerprint',
    'GroupCallRecentSpeaker',
    'Hashtags',
    'HideSuggestedAction',
    'HttpUrl',
    'IdentityDocument',
    'ImportContacts',
    'ImportMessages',
    'ImportedContacts',
    'InlineKeyboardButton',
    'InlineKeyboardButtonType',
    'InlineKeyboardButtonTypeBuy',
    'InlineKeyboardButtonTypeCallback',
    'InlineKeyboardButtonTypeCallbackGame',
    'InlineKeyboardButtonTypeCallbackWithPassword',
    'InlineKeyboardButtonTypeLoginUrl',
    'InlineKeyboardButtonTypeSwitchInline',
    'InlineKeyboardButtonTypeUrl',
    'InlineQueryResult',
    'InlineQueryResultAnimation',
    'InlineQueryResultArticle',
    'InlineQueryResultAudio',
    'InlineQueryResultContact',
    'InlineQueryResultDocument',
    'InlineQueryResultGame',
    'InlineQueryResultLocation',
    'InlineQueryResultPhoto',
    'InlineQueryResultSticker',
    'InlineQueryResultVenue',
    'InlineQueryResultVideo',
    'InlineQueryResultVoiceNote',
    'InlineQueryResults',
    'InputBackground',
    'InputBackgroundLocal',
    'InputBackgroundRemote',
    'InputChatPhoto',
    'InputChatPhotoAnimation',
    'InputChatPhotoPrevious',
    'InputChatPhotoStatic',
    'InputCredentials',
    'InputCredentialsApplePay',
    'InputCredentialsGooglePay',
    'InputCredentialsNew',
    'InputCredentialsSaved',
    'InputFile',
    'InputFileGenerated',
    'InputFileId',
    'InputFileLocal',
    'InputFileRemote',
    'InputIdentityDocument',
    'InputInlineQueryResult',
    'InputInlineQueryResultAnimation',
    'InputInlineQueryResultArticle',
    'InputInlineQueryResultAudio',
    'InputInlineQueryResultContact',
    'InputInlineQueryResultDocument',
    'InputInlineQueryResultGame',
    'InputInlineQueryResultLocation',
    'InputInlineQueryResultPhoto',
    'InputInlineQueryResultSticker',
    'InputInlineQueryResultVenue',
    'InputInlineQueryResultVideo',
    'InputInlineQueryResultVoiceNote',
    'InputMessageContent',
    'InputMessageAnimation',
    'InputMessageAudio',
    'InputMessageContact',
    'InputMessageDice',
    'InputMessageDocument',
    'InputMessageForwarded',
    'InputMessageGame',
    'InputMessageInvoice',
    'InputMessageLocation',
    'InputMessagePhoto',
    'InputMessagePoll',
    'InputMessageSticker',
    'InputMessageText',
    'InputMessageVenue',
    'InputMessageVideo',
    'InputMessageVideoNote',
    'InputMessageVoiceNote',
    'InputPassportElement',
    'InputPassportElementAddress',
    'InputPassportElementBankStatement',
    'InputPassportElementDriverLicense',
    'InputPassportElementEmailAddress',
    'InputPassportElementIdentityCard',
    'InputPassportElementInternalPassport',
    'InputPassportElementPassport',
    'InputPassportElementPassportRegistration',
    'InputPassportElementPersonalDetails',
    'InputPassportElementPhoneNumber',
    'InputPassportElementRentalAgreement',
    'InputPassportElementTemporaryRegistration',
    'InputPassportElementUtilityBill',
    'InputPassportElementError',
    'InputPassportElementErrorSource',
    'InputPassportElementErrorSourceDataField',
    'InputPassportElementErrorSourceFile',
    'InputPassportElementErrorSourceFiles',
    'InputPassportElementErrorSourceFrontSide',
    'InputPassportElementErrorSourceReverseSide',
    'InputPassportElementErrorSourceSelfie',
    'InputPassportElementErrorSourceTranslationFile',
    'InputPassportElementErrorSourceTranslationFiles',
    'InputPassportElementErrorSourceUnspecified',
    'InputPersonalDocument',
    'InputSticker',
    'InputStickerAnimated',
    'InputStickerStatic',
    'InputThumbnail',
    'InviteGroupCallParticipants',
    'Invoice',
    'JoinChat',
    'JoinChatByInviteLink',
    'JoinGroupCall',
    'JsonValue',
    'JsonValueArray',
    'JsonValueBoolean',
    'JsonValueNull',
    'JsonValueNumber',
    'JsonValueObject',
    'JsonValueString',
    'KeyboardButton',
    'KeyboardButtonType',
    'KeyboardButtonTypeRequestLocation',
    'KeyboardButtonTypeRequestPhoneNumber',
    'KeyboardButtonTypeRequestPoll',
    'KeyboardButtonTypeText',
    'LabeledPricePart',
    'LanguagePackInfo',
    'LanguagePackString',
    'LanguagePackStringValue',
    'LanguagePackStringValueDeleted',
    'LanguagePackStringValueOrdinary',
    'LanguagePackStringValuePluralized',
    'LanguagePackStrings',
    'LeaveChat',
    'LeaveGroupCall',
    'LoadGroupCallParticipants',
    'LocalFile',
    'LocalizationTargetInfo',
    'Location',
    'LogOut',
    'LogStream',
    'LogStreamDefault',
    'LogStreamEmpty',
    'LogStreamFile',
    'LogTags',
    'LogVerbosityLevel',
    'LoginUrlInfo',
    'LoginUrlInfoOpen',
    'LoginUrlInfoRequestConfirmation',
    'MaskPoint',
    'MaskPointChin',
    'MaskPointEyes',
    'MaskPointForehead',
    'MaskPointMouth',
    'MaskPosition',
    'Message',
    'MessageContent',
    'MessageAnimation',
    'MessageAudio',
    'MessageBasicGroupChatCreate',
    'MessageCall',
    'MessageChatAddMembers',
    'MessageChatChangePhoto',
    'MessageChatChangeTitle',
    'MessageChatDeleteMember',
    'MessageChatDeletePhoto',
    'MessageChatJoinByLink',
    'MessageChatSetTtl',
    'MessageChatUpgradeFrom',
    'MessageChatUpgradeTo',
    'MessageContact',
    'MessageContactRegistered',
    'MessageCustomServiceAction',
    'MessageDice',
    'MessageDocument',
    'MessageExpiredPhoto',
    'MessageExpiredVideo',
    'MessageGame',
    'MessageGameScore',
    'MessageInviteVoiceChatParticipants',
    'MessageInvoice',
    'MessageLocation',
    'MessagePassportDataReceived',
    'MessagePassportDataSent',
    'MessagePaymentSuccessful',
    'MessagePaymentSuccessfulBot',
    'MessagePhoto',
    'MessagePinMessage',
    'MessagePoll',
    'MessageProximityAlertTriggered',
    'MessageScreenshotTaken',
    'MessageSticker',
    'MessageSupergroupChatCreate',
    'MessageText',
    'MessageUnsupported',
    'MessageVenue',
    'MessageVideo',
    'MessageVideoNote',
    'MessageVoiceChatEnded',
    'MessageVoiceChatStarted',
    'MessageVoiceNote',
    'MessageWebsiteConnected',
    'MessageCopyOptions',
    'MessageFileType',
    'MessageFileTypeGroup',
    'MessageFileTypePrivate',
    'MessageFileTypeUnknown',
    'MessageForwardInfo',
    'MessageForwardOrigin',
    'MessageForwardOriginChannel',
    'MessageForwardOriginChat',
    'MessageForwardOriginHiddenUser',
    'MessageForwardOriginMessageImport',
    'MessageForwardOriginUser',
    'MessageInteractionInfo',
    'MessageLink',
    'MessageLinkInfo',
    'MessageReplyInfo',
    'MessageSchedulingState',
    'MessageSchedulingStateSendAtDate',
    'MessageSchedulingStateSendWhenOnline',
    'MessageSendOptions',
    'MessageSender',
    'MessageSenderChat',
    'MessageSenderUser',
    'MessageSenders',
    'MessageSendingState',
    'MessageSendingStateFailed',
    'MessageSendingStatePending',
    'MessageStatistics',
    'MessageThreadInfo',
    'Messages',
    'Minithumbnail',
    'NetworkStatistics',
    'NetworkStatisticsEntry',
    'NetworkStatisticsEntryCall',
    'NetworkStatisticsEntryFile',
    'NetworkType',
    'NetworkTypeMobile',
    'NetworkTypeMobileRoaming',
    'NetworkTypeNone',
    'NetworkTypeOther',
    'NetworkTypeWiFi',
    'Notification',
    'NotificationGroup',
    'NotificationGroupType',
    'NotificationGroupTypeCalls',
    'NotificationGroupTypeMentions',
    'NotificationGroupTypeMessages',
    'NotificationGroupTypeSecretChat',
    'NotificationSettingsScope',
    'NotificationSettingsScopeChannelChats',
    'NotificationSettingsScopeGroupChats',
    'NotificationSettingsScopePrivateChats',
    'NotificationType',
    'NotificationTypeNewCall',
    'NotificationTypeNewMessage',
    'NotificationTypeNewPushMessage',
    'NotificationTypeNewSecretChat',
    'Ok',
    'OpenChat',
    'OpenMessageContent',
    'OptimizeStorage',
    'OptionValue',
    'OptionValueBoolean',
    'OptionValueEmpty',
    'OptionValueInteger',
    'OptionValueString',
    'OrderInfo',
    'PageBlock',
    'PageBlockAnchor',
    'PageBlockAnimation',
    'PageBlockAudio',
    'PageBlockAuthorDate',
    'PageBlockBlockQuote',
    'PageBlockChatLink',
    'PageBlockCollage',
    'PageBlockCover',
    'PageBlockDetails',
    'PageBlockDivider',
    'PageBlockEmbedded',
    'PageBlockEmbeddedPost',
    'PageBlockFooter',
    'PageBlockHeader',
    'PageBlockKicker',
    'PageBlockList',
    'PageBlockMap',
    'PageBlockParagraph',
    'PageBlockPhoto',
    'PageBlockPreformatted',
    'PageBlockPullQuote',
    'PageBlockRelatedArticles',
    'PageBlockSlideshow',
    'PageBlockSubheader',
    'PageBlockSubtitle',
    'PageBlockTable',
    'PageBlockTitle',
    'PageBlockVideo',
    'PageBlockVoiceNote',
    'PageBlockCaption',
    'PageBlockHorizontalAlignment',
    'PageBlockHorizontalAlignmentCenter',
    'PageBlockHorizontalAlignmentLeft',
    'PageBlockHorizontalAlignmentRight',
    'PageBlockRelatedArticle',
    'PageBlockTableCell',
    'PageBlockVerticalAlignment',
    'PageBlockVerticalAlignmentBottom',
    'PageBlockVerticalAlignmentMiddle',
    'PageBlockVerticalAlignmentTop',
    'ParseMarkdown',
    'ParseTextEntities',
    'PassportAuthorizationForm',
    'PassportElement',
    'PassportElementAddress',
    'PassportElementBankStatement',
    'PassportElementDriverLicense',
    'PassportElementEmailAddress',
    'PassportElementIdentityCard',
    'PassportElementInternalPassport',
    'PassportElementPassport',
    'PassportElementPassportRegistration',
    'PassportElementPersonalDetails',
    'PassportElementPhoneNumber',
    'PassportElementRentalAgreement',
    'PassportElementTemporaryRegistration',
    'PassportElementUtilityBill',
    'PassportElementError',
    'PassportElementErrorSource',
    'PassportElementErrorSourceDataField',
    'PassportElementErrorSourceFile',
    'PassportElementErrorSourceFiles',
    'PassportElementErrorSourceFrontSide',
    'PassportElementErrorSourceReverseSide',
    'PassportElementErrorSourceSelfie',
    'PassportElementErrorSourceTranslationFile',
    'PassportElementErrorSourceTranslationFiles',
    'PassportElementErrorSourceUnspecified',
    'PassportElementType',
    'PassportElementTypeAddress',
    'PassportElementTypeBankStatement',
    'PassportElementTypeDriverLicense',
    'PassportElementTypeEmailAddress',
    'PassportElementTypeIdentityCard',
    'PassportElementTypeInternalPassport',
    'PassportElementTypePassport',
    'PassportElementTypePassportRegistration',
    'PassportElementTypePersonalDetails',
    'PassportElementTypePhoneNumber',
    'PassportElementTypeRentalAgreement',
    'PassportElementTypeTemporaryRegistration',
    'PassportElementTypeUtilityBill',
    'PassportElements',
    'PassportElementsWithErrors',
    'PassportRequiredElement',
    'PassportSuitableElement',
    'PasswordState',
    'PaymentForm',
    'PaymentReceipt',
    'PaymentResult',
    'PaymentsProviderStripe',
    'PersonalDetails',
    'PersonalDocument',
    'PhoneNumberAuthenticationSettings',
    'PhoneNumberInfo',
    'Photo',
    'PhotoSize',
    'PinChatMessage',
    'PingProxy',
    'Point',
    'Poll',
    'PollOption',
    'PollType',
    'PollTypeQuiz',
    'PollTypeRegular',
    'ProcessPushNotification',
    'ProfilePhoto',
    'Proxies',
    'Proxy',
    'ProxyType',
    'ProxyTypeHttp',
    'ProxyTypeMtproto',
    'ProxyTypeSocks5',
    'PublicChatType',
    'PublicChatTypeHasUsername',
    'PublicChatTypeIsLocationBased',
    'PushMessageContent',
    'PushMessageContentAnimation',
    'PushMessageContentAudio',
    'PushMessageContentBasicGroupChatCreate',
    'PushMessageContentChatAddMembers',
    'PushMessageContentChatChangePhoto',
    'PushMessageContentChatChangeTitle',
    'PushMessageContentChatDeleteMember',
    'PushMessageContentChatJoinByLink',
    'PushMessageContentContact',
    'PushMessageContentContactRegistered',
    'PushMessageContentDocument',
    'PushMessageContentGame',
    'PushMessageContentGameScore',
    'PushMessageContentHidden',
    'PushMessageContentInvoice',
    'PushMessageContentLocation',
    'PushMessageContentMediaAlbum',
    'PushMessageContentMessageForwards',
    'PushMessageContentPhoto',
    'PushMessageContentPoll',
    'PushMessageContentScreenshotTaken',
    'PushMessageContentSticker',
    'PushMessageContentText',
    'PushMessageContentVideo',
    'PushMessageContentVideoNote',
    'PushMessageContentVoiceNote',
    'PushReceiverId',
    'ReadAllChatMentions',
    'ReadFilePart',
    'RecommendedChatFilter',
    'RecommendedChatFilters',
    'RecoverAuthenticationPassword',
    'RecoverPassword',
    'RecoveryEmailAddress',
    'RegisterDevice',
    'RegisterUser',
    'RemoteFile',
    'RemoveBackground',
    'RemoveChatActionBar',
    'RemoveContacts',
    'RemoveFavoriteSticker',
    'RemoveNotification',
    'RemoveNotificationGroup',
    'RemoveProxy',
    'RemoveRecentHashtag',
    'RemoveRecentSticker',
    'RemoveRecentlyFoundChat',
    'RemoveSavedAnimation',
    'RemoveStickerFromSet',
    'RemoveTopChat',
    'ReorderChatFilters',
    'ReorderInstalledStickerSets',
    'ReplacePrimaryChatInviteLink',
    'ReplyMarkup',
    'ReplyMarkupForceReply',
    'ReplyMarkupInlineKeyboard',
    'ReplyMarkupRemoveKeyboard',
    'ReplyMarkupShowKeyboard',
    'ReportChat',
    'ReportChatPhoto',
    'ReportSupergroupSpam',
    'RequestAuthenticationPasswordRecovery',
    'RequestPasswordRecovery',
    'RequestQrCodeAuthentication',
    'ResendAuthenticationCode',
    'ResendChangePhoneNumberCode',
    'ResendEmailAddressVerificationCode',
    'ResendMessages',
    'ResendPhoneNumberConfirmationCode',
    'ResendPhoneNumberVerificationCode',
    'ResendRecoveryEmailAddressCode',
    'ResetAllNotificationSettings',
    'ResetBackgrounds',
    'ResetNetworkStatistics',
    'RevokeChatInviteLink',
    'RevokeGroupCallInviteLink',
    'RichText',
    'RichTextAnchor',
    'RichTextAnchorLink',
    'RichTextBold',
    'RichTextEmailAddress',
    'RichTextFixed',
    'RichTextIcon',
    'RichTextItalic',
    'RichTextMarked',
    'RichTextPhoneNumber',
    'RichTextPlain',
    'RichTextReference',
    'RichTextStrikethrough',
    'RichTextSubscript',
    'RichTextSuperscript',
    'RichTextUnderline',
    'RichTextUrl',
    'RichTexts',
    'SaveApplicationLogEvent',
    'SavedCredentials',
    'ScopeNotificationSettings',
    'SearchBackground',
    'SearchCallMessages',
    'SearchChatMembers',
    'SearchChatMessages',
    'SearchChatRecentLocationMessages',
    'SearchChats',
    'SearchChatsNearby',
    'SearchChatsOnServer',
    'SearchContacts',
    'SearchEmojis',
    'SearchHashtags',
    'SearchInstalledStickerSets',
    'SearchMessages',
    'SearchMessagesFilter',
    'SearchMessagesFilterAnimation',
    'SearchMessagesFilterAudio',
    'SearchMessagesFilterCall',
    'SearchMessagesFilterChatPhoto',
    'SearchMessagesFilterDocument',
    'SearchMessagesFilterEmpty',
    'SearchMessagesFilterFailedToSend',
    'SearchMessagesFilterMention',
    'SearchMessagesFilterMissedCall',
    'SearchMessagesFilterPhoto',
    'SearchMessagesFilterPhotoAndVideo',
    'SearchMessagesFilterPinned',
    'SearchMessagesFilterUnreadMention',
    'SearchMessagesFilterUrl',
    'SearchMessagesFilterVideo',
    'SearchMessagesFilterVideoNote',
    'SearchMessagesFilterVoiceAndVideoNote',
    'SearchMessagesFilterVoiceNote',
    'SearchPublicChat',
    'SearchPublicChats',
    'SearchSecretMessages',
    'SearchStickerSet',
    'SearchStickerSets',
    'SearchStickers',
    'Seconds',
    'SecretChat',
    'SecretChatState',
    'SecretChatStateClosed',
    'SecretChatStatePending',
    'SecretChatStateReady',
    'SendBotStartMessage',
    'SendCallDebugInformation',
    'SendCallRating',
    'SendCallSignalingData',
    'SendChatAction',
    'SendChatScreenshotTakenNotification',
    'SendCustomRequest',
    'SendEmailAddressVerificationCode',
    'SendInlineQueryResultMessage',
    'SendMessage',
    'SendMessageAlbum',
    'SendPassportAuthorizationForm',
    'SendPaymentForm',
    'SendPhoneNumberConfirmationCode',
    'SendPhoneNumberVerificationCode',
    'Session',
    'Sessions',
    'SetAccountTtl',
    'SetAlarm',
    'SetAuthenticationPhoneNumber',
    'SetAutoDownloadSettings',
    'SetBackground',
    'SetBio',
    'SetBotUpdatesStatus',
    'SetChatClientData',
    'SetChatDescription',
    'SetChatDiscussionGroup',
    'SetChatDraftMessage',
    'SetChatLocation',
    'SetChatMemberStatus',
    'SetChatMessageTtlSetting',
    'SetChatNotificationSettings',
    'SetChatPermissions',
    'SetChatPhoto',
    'SetChatSlowModeDelay',
    'SetChatTitle',
    'SetCommands',
    'SetCustomLanguagePack',
    'SetCustomLanguagePackString',
    'SetDatabaseEncryptionKey',
    'SetFileGenerationProgress',
    'SetGameScore',
    'SetGroupCallParticipantIsSpeaking',
    'SetGroupCallParticipantVolumeLevel',
    'SetGroupCallTitle',
    'SetInlineGameScore',
    'SetLocation',
    'SetLogStream',
    'SetLogTagVerbosityLevel',
    'SetLogVerbosityLevel',
    'SetName',
    'SetNetworkType',
    'SetOption',
    'SetPassportElement',
    'SetPassportElementErrors',
    'SetPassword',
    'SetPinnedChats',
    'SetPollAnswer',
    'SetProfilePhoto',
    'SetRecoveryEmailAddress',
    'SetScopeNotificationSettings',
    'SetStickerPositionInSet',
    'SetStickerSetThumbnail',
    'SetSupergroupStickerSet',
    'SetSupergroupUsername',
    'SetTdlibParameters',
    'SetUserPrivacySettingRules',
    'SetUsername',
    'SharePhoneNumber',
    'ShippingOption',
    'StartGroupCallRecording',
    'StatisticalGraph',
    'StatisticalGraphAsync',
    'StatisticalGraphData',
    'StatisticalGraphError',
    'StatisticalValue',
    'Sticker',
    'StickerSet',
    'StickerSetInfo',
    'StickerSets',
    'Stickers',
    'StopPoll',
    'StorageStatistics',
    'StorageStatisticsByChat',
    'StorageStatisticsByFileType',
    'StorageStatisticsFast',
    'SuggestedAction',
    'SuggestedActionCheckPhoneNumber',
    'SuggestedActionConvertToBroadcastGroup',
    'SuggestedActionEnableArchiveAndMuteNewChats',
    'SuggestedActionSeeTicksHint',
    'Supergroup',
    'SupergroupFullInfo',
    'SupergroupMembersFilter',
    'SupergroupMembersFilterAdministrators',
    'SupergroupMembersFilterBanned',
    'SupergroupMembersFilterBots',
    'SupergroupMembersFilterContacts',
    'SupergroupMembersFilterMention',
    'SupergroupMembersFilterRecent',
    'SupergroupMembersFilterRestricted',
    'SupergroupMembersFilterSearch',
    'SynchronizeLanguagePack',
    'TMeUrl',
    'TMeUrlType',
    'TMeUrlTypeChatInvite',
    'TMeUrlTypeStickerSet',
    'TMeUrlTypeSupergroup',
    'TMeUrlTypeUser',
    'TMeUrls',
    'TdlibParameters',
    'TemporaryPasswordState',
    'TerminateAllOtherSessions',
    'TerminateSession',
    'TermsOfService',
    'TestBytes',
    'TestCallBytes',
    'TestCallEmpty',
    'TestCallString',
    'TestCallVectorInt',
    'TestCallVectorIntObject',
    'TestCallVectorString',
    'TestCallVectorStringObject',
    'TestGetDifference',
    'TestInt',
    'TestNetwork',
    'TestProxy',
    'TestReturnError',
    'TestSquareInt',
    'TestString',
    'TestUseUpdate',
    'TestVectorInt',
    'TestVectorIntObject',
    'TestVectorString',
    'TestVectorStringObject',
    'Text',
    'TextEntities',
    'TextEntity',
    'TextEntityType',
    'TextEntityTypeBankCardNumber',
    'TextEntityTypeBold',
    'TextEntityTypeBotCommand',
    'TextEntityTypeCashtag',
    'TextEntityTypeCode',
    'TextEntityTypeEmailAddress',
    'TextEntityTypeHashtag',
    'TextEntityTypeItalic',
    'TextEntityTypeMention',
    'TextEntityTypeMentionName',
    'TextEntityTypePhoneNumber',
    'TextEntityTypePre',
    'TextEntityTypePreCode',
    'TextEntityTypeStrikethrough',
    'TextEntityTypeTextUrl',
    'TextEntityTypeUnderline',
    'TextEntityTypeUrl',
    'TextParseMode',
    'TextParseModeHTML',
    'TextParseModeMarkdown',
    'Thumbnail',
    'ThumbnailFormat',
    'ThumbnailFormatGif',
    'ThumbnailFormatJpeg',
    'ThumbnailFormatMpeg4',
    'ThumbnailFormatPng',
    'ThumbnailFormatTgs',
    'ThumbnailFormatWebp',
    'ToggleChatDefaultDisableNotification',
    'ToggleChatIsMarkedAsUnread',
    'ToggleChatIsPinned',
    'ToggleGroupCallMuteNewParticipants',
    'ToggleGroupCallParticipantIsHandRaised',
    'ToggleGroupCallParticipantIsMuted',
    'ToggleMessageSenderIsBlocked',
    'ToggleSupergroupIsAllHistoryAvailable',
    'ToggleSupergroupIsBroadcastGroup',
    'ToggleSupergroupSignMessages',
    'TopChatCategory',
    'TopChatCategoryBots',
    'TopChatCategoryCalls',
    'TopChatCategoryChannels',
    'TopChatCategoryForwardChats',
    'TopChatCategoryGroups',
    'TopChatCategoryInlineBots',
    'TopChatCategoryUsers',
    'TransferChatOwnership',
    'UnpinAllChatMessages',
    'UnpinChatMessage',
    'Update',
    'UpdateActiveNotifications',
    'UpdateAnimationSearchParameters',
    'UpdateAuthorizationState',
    'UpdateBasicGroup',
    'UpdateBasicGroupFullInfo',
    'UpdateCall',
    'UpdateChatActionBar',
    'UpdateChatDefaultDisableNotification',
    'UpdateChatDraftMessage',
    'UpdateChatFilters',
    'UpdateChatHasScheduledMessages',
    'UpdateChatIsBlocked',
    'UpdateChatIsMarkedAsUnread',
    'UpdateChatLastMessage',
    'UpdateChatMember',
    'UpdateChatMessageTtlSetting',
    'UpdateChatNotificationSettings',
    'UpdateChatOnlineMemberCount',
    'UpdateChatPermissions',
    'UpdateChatPhoto',
    'UpdateChatPosition',
    'UpdateChatReadInbox',
    'UpdateChatReadOutbox',
    'UpdateChatReplyMarkup',
    'UpdateChatTitle',
    'UpdateChatUnreadMentionCount',
    'UpdateChatVoiceChat',
    'UpdateConnectionState',
    'UpdateDeleteMessages',
    'UpdateDiceEmojis',
    'UpdateFavoriteStickers',
    'UpdateFile',
    'UpdateFileGenerationStart',
    'UpdateFileGenerationStop',
    'UpdateGroupCall',
    'UpdateGroupCallParticipant',
    'UpdateHavePendingNotifications',
    'UpdateInstalledStickerSets',
    'UpdateLanguagePackStrings',
    'UpdateMessageContent',
    'UpdateMessageContentOpened',
    'UpdateMessageEdited',
    'UpdateMessageInteractionInfo',
    'UpdateMessageIsPinned',
    'UpdateMessageLiveLocationViewed',
    'UpdateMessageMentionRead',
    'UpdateMessageSendAcknowledged',
    'UpdateMessageSendFailed',
    'UpdateMessageSendSucceeded',
    'UpdateNewCallSignalingData',
    'UpdateNewCallbackQuery',
    'UpdateNewChat',
    'UpdateNewChosenInlineResult',
    'UpdateNewCustomEvent',
    'UpdateNewCustomQuery',
    'UpdateNewInlineCallbackQuery',
    'UpdateNewInlineQuery',
    'UpdateNewMessage',
    'UpdateNewPreCheckoutQuery',
    'UpdateNewShippingQuery',
    'UpdateNotification',
    'UpdateNotificationGroup',
    'UpdateOption',
    'UpdatePoll',
    'UpdatePollAnswer',
    'UpdateRecentStickers',
    'UpdateSavedAnimations',
    'UpdateScopeNotificationSettings',
    'UpdateSecretChat',
    'UpdateSelectedBackground',
    'UpdateServiceNotification',
    'UpdateStickerSet',
    'UpdateSuggestedActions',
    'UpdateSupergroup',
    'UpdateSupergroupFullInfo',
    'UpdateTermsOfService',
    'UpdateTrendingStickerSets',
    'UpdateUnreadChatCount',
    'UpdateUnreadMessageCount',
    'UpdateUser',
    'UpdateUserChatAction',
    'UpdateUserFullInfo',
    'UpdateUserPrivacySettingRules',
    'UpdateUserStatus',
    'UpdateUsersNearby',
    'Updates',
    'UpgradeBasicGroupChatToSupergroupChat',
    'UploadFile',
    'UploadStickerFile',
    'User',
    'UserFullInfo',
    'UserPrivacySetting',
    'UserPrivacySettingAllowCalls',
    'UserPrivacySettingAllowChatInvites',
    'UserPrivacySettingAllowFindingByPhoneNumber',
    'UserPrivacySettingAllowPeerToPeerCalls',
    'UserPrivacySettingShowLinkInForwardedMessages',
    'UserPrivacySettingShowPhoneNumber',
    'UserPrivacySettingShowProfilePhoto',
    'UserPrivacySettingShowStatus',
    'UserPrivacySettingRule',
    'UserPrivacySettingRuleAllowAll',
    'UserPrivacySettingRuleAllowChatMembers',
    'UserPrivacySettingRuleAllowContacts',
    'UserPrivacySettingRuleAllowUsers',
    'UserPrivacySettingRuleRestrictAll',
    'UserPrivacySettingRuleRestrictChatMembers',
    'UserPrivacySettingRuleRestrictContacts',
    'UserPrivacySettingRuleRestrictUsers',
    'UserPrivacySettingRules',
    'UserStatus',
    'UserStatusEmpty',
    'UserStatusLastMonth',
    'UserStatusLastWeek',
    'UserStatusOffline',
    'UserStatusOnline',
    'UserStatusRecently',
    'UserType',
    'UserTypeBot',
    'UserTypeDeleted',
    'UserTypeRegular',
    'UserTypeUnknown',
    'Users',
    'ValidateOrderInfo',
    'ValidatedOrderInfo',
    'VectorPathCommand',
    'VectorPathCommandCubicBezierCurve',
    'VectorPathCommandLine',
    'Venue',
    'Video',
    'VideoNote',
    'ViewMessages',
    'ViewTrendingStickerSets',
    'VoiceChat',
    'VoiceNote',
    'WebPage',
    'WebPageInstantView',
    'WriteGeneratedFilePart',
]



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetLogStream(BaseObject):
    """
    Returns information about currently used log stream for internal logging of TDLib. Can be called synchronously
    
    """

    ID: str = Field("getLogStream", alias="@type")

    @staticmethod
    def read(q: dict) -> GetLogStream:
        return GetLogStream.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetJsonValue(BaseObject):
    """
    Converts a JSON-serialized string to corresponding JsonValue object. Can be called synchronously
    
    Params:
        json_ (:class:`str`)
            The JSON-serialized string
        
    """

    ID: str = Field("getJsonValue", alias="@type")
    json_: str = Field(..., alias='json')

    @staticmethod
    def read(q: dict) -> GetJsonValue:
        return GetJsonValue.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetInlineGameScore(BaseObject):
    """
    Updates the game score of the specified user in a game; for bots only
    
    Params:
        inline_message_id (:class:`str`)
            Inline message identifier
        
        edit_message (:class:`bool`)
            True, if the message should be edited
        
        user_id (:class:`int`)
            User identifier
        
        score (:class:`int`)
            The new score
        
        force (:class:`bool`)
            Pass true to update the score even if it decreases. If the score is 0, the user will be deleted from the high score table
        
    """

    ID: str = Field("setInlineGameScore", alias="@type")
    inline_message_id: str
    edit_message: bool
    user_id: int
    score: int
    force: bool

    @staticmethod
    def read(q: dict) -> SetInlineGameScore:
        return SetInlineGameScore.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import Contact


class ImportContacts(BaseObject):
    """
    Adds new contacts or edits existing contacts by their phone numbers; contacts' user identifiers are ignored
    
    Params:
        contacts (:obj:`list[Contact]`)
            The list of contacts to import or edit; contacts' vCard are ignored and are not imported
        
    """

    ID: str = Field("importContacts", alias="@type")
    contacts: list[Contact]

    @staticmethod
    def read(q: dict) -> ImportContacts:
        return ImportContacts.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .shipping_option import ShippingOption
from ..base_object import BaseObject


class ValidatedOrderInfo(BaseObject):
    """
    Contains a temporary identifier of validated order information, which is stored for one hour. Also contains the available shipping options
    
    Params:
        order_info_id (:class:`str`)
            Temporary identifier of the order information
        
        shipping_options (:obj:`list[ShippingOption]`)
            Available shipping options
        
    """

    ID: str = Field("validatedOrderInfo", alias="@type")
    order_info_id: str
    shipping_options: list[ShippingOption]

    @staticmethod
    def read(q: dict) -> ValidatedOrderInfo:
        return ValidatedOrderInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetGroupCallInviteLink(BaseObject):
    """
    Returns invite link to a voice chat in a public chat
    
    Params:
        group_call_id (:class:`int`)
            Group call identifier
        
        can_self_unmute (:class:`bool`)
            Pass true if the invite_link should contain an invite hash, passing which to joinGroupCall would allow the invited user to unmute themself. Requires groupCall.can_be_managed group call flag
        
    """

    ID: str = Field("getGroupCallInviteLink", alias="@type")
    group_call_id: int
    can_self_unmute: bool

    @staticmethod
    def read(q: dict) -> GetGroupCallInviteLink:
        return GetGroupCallInviteLink.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatAction(BaseObject):
    """
    Describes the different types of activity in a chat
    
    """

    ID: str = Field("chatAction", alias="@type")


class ChatActionCancel(ChatAction):
    """
    The user has cancelled the previous action
    
    """

    ID: str = Field("chatActionCancel", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatActionCancel:
        return ChatActionCancel.construct(**q)


class ChatActionChoosingContact(ChatAction):
    """
    The user is picking a contact to send
    
    """

    ID: str = Field("chatActionChoosingContact", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatActionChoosingContact:
        return ChatActionChoosingContact.construct(**q)


class ChatActionChoosingLocation(ChatAction):
    """
    The user is picking a location or venue to send
    
    """

    ID: str = Field("chatActionChoosingLocation", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatActionChoosingLocation:
        return ChatActionChoosingLocation.construct(**q)


class ChatActionRecordingVideo(ChatAction):
    """
    The user is recording a video
    
    """

    ID: str = Field("chatActionRecordingVideo", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatActionRecordingVideo:
        return ChatActionRecordingVideo.construct(**q)


class ChatActionRecordingVideoNote(ChatAction):
    """
    The user is recording a video note
    
    """

    ID: str = Field("chatActionRecordingVideoNote", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatActionRecordingVideoNote:
        return ChatActionRecordingVideoNote.construct(**q)


class ChatActionRecordingVoiceNote(ChatAction):
    """
    The user is recording a voice note
    
    """

    ID: str = Field("chatActionRecordingVoiceNote", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatActionRecordingVoiceNote:
        return ChatActionRecordingVoiceNote.construct(**q)


class ChatActionStartPlayingGame(ChatAction):
    """
    The user has started to play a game
    
    """

    ID: str = Field("chatActionStartPlayingGame", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatActionStartPlayingGame:
        return ChatActionStartPlayingGame.construct(**q)


class ChatActionTyping(ChatAction):
    """
    The user is typing a message
    
    """

    ID: str = Field("chatActionTyping", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatActionTyping:
        return ChatActionTyping.construct(**q)


class ChatActionUploadingDocument(ChatAction):
    """
    The user is uploading a document
    
    Params:
        progress (:class:`int`)
            Upload progress, as a percentage
        
    """

    ID: str = Field("chatActionUploadingDocument", alias="@type")
    progress: int

    @staticmethod
    def read(q: dict) -> ChatActionUploadingDocument:
        return ChatActionUploadingDocument.construct(**q)


class ChatActionUploadingPhoto(ChatAction):
    """
    The user is uploading a photo
    
    Params:
        progress (:class:`int`)
            Upload progress, as a percentage
        
    """

    ID: str = Field("chatActionUploadingPhoto", alias="@type")
    progress: int

    @staticmethod
    def read(q: dict) -> ChatActionUploadingPhoto:
        return ChatActionUploadingPhoto.construct(**q)


class ChatActionUploadingVideo(ChatAction):
    """
    The user is uploading a video
    
    Params:
        progress (:class:`int`)
            Upload progress, as a percentage
        
    """

    ID: str = Field("chatActionUploadingVideo", alias="@type")
    progress: int

    @staticmethod
    def read(q: dict) -> ChatActionUploadingVideo:
        return ChatActionUploadingVideo.construct(**q)


class ChatActionUploadingVideoNote(ChatAction):
    """
    The user is uploading a video note
    
    Params:
        progress (:class:`int`)
            Upload progress, as a percentage
        
    """

    ID: str = Field("chatActionUploadingVideoNote", alias="@type")
    progress: int

    @staticmethod
    def read(q: dict) -> ChatActionUploadingVideoNote:
        return ChatActionUploadingVideoNote.construct(**q)


class ChatActionUploadingVoiceNote(ChatAction):
    """
    The user is uploading a voice note
    
    Params:
        progress (:class:`int`)
            Upload progress, as a percentage
        
    """

    ID: str = Field("chatActionUploadingVoiceNote", alias="@type")
    progress: int

    @staticmethod
    def read(q: dict) -> ChatActionUploadingVoiceNote:
        return ChatActionUploadingVoiceNote.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import JsonValue


class GetJsonString(BaseObject):
    """
    Converts a JsonValue object to corresponding JSON-serialized string. Can be called synchronously
    
    Params:
        json_value (:class:`JsonValue`)
            The JsonValue object
        
    """

    ID: str = Field("getJsonString", alias="@type")
    json_value: JsonValue

    @staticmethod
    def read(q: dict) -> GetJsonString:
        return GetJsonString.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetLanguagePackInfo(BaseObject):
    """
    Returns information about a language pack. Returned language pack identifier may be different from a provided one. Can be called before authorization
    
    Params:
        language_pack_id (:class:`str`)
            Language pack identifier
        
    """

    ID: str = Field("getLanguagePackInfo", alias="@type")
    language_pack_id: str

    @staticmethod
    def read(q: dict) -> GetLanguagePackInfo:
        return GetLanguagePackInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SearchChats(BaseObject):
    """
    Searches for the specified query in the title and username of already known chats, this is an offline request. Returns chats in the order seen in the main chat list
    
    Params:
        query (:class:`str`)
            Query to search for. If the query is empty, returns up to 20 recently found chats
        
        limit (:class:`int`)
            The maximum number of chats to be returned
        
    """

    ID: str = Field("searchChats", alias="@type")
    query: str
    limit: int

    @staticmethod
    def read(q: dict) -> SearchChats:
        return SearchChats.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetPreferredCountryLanguage(BaseObject):
    """
    Returns an IETF language tag of the language preferred in the country, which should be used to fill native fields in Telegram Passport personal details. Returns a 404 error if unknown
    
    Params:
        country_code (:class:`str`)
            A two-letter ISO 3166-1 alpha-2 country code
        
    """

    ID: str = Field("getPreferredCountryLanguage", alias="@type")
    country_code: str

    @staticmethod
    def read(q: dict) -> GetPreferredCountryLanguage:
        return GetPreferredCountryLanguage.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetAuthorizationState(BaseObject):
    """
    Returns the current authorization state; this is an offline request. For informational purposes only. Use updateAuthorizationState instead to maintain the current authorization state. Can be called before initialization
    
    """

    ID: str = Field("getAuthorizationState", alias="@type")

    @staticmethod
    def read(q: dict) -> GetAuthorizationState:
        return GetAuthorizationState.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetExternalLinkInfo(BaseObject):
    """
    Returns information about an action to be done when the current user clicks an HTTP link. This method can be used to automatically authorize the current user on a website. Don't use this method for links from secret chats if link preview is disabled in secret chats
    
    Params:
        link (:class:`str`)
            The HTTP link
        
    """

    ID: str = Field("getExternalLinkInfo", alias="@type")
    link: str

    @staticmethod
    def read(q: dict) -> GetExternalLinkInfo:
        return GetExternalLinkInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from ..base_object import BaseObject


class SetName(BaseObject):
    """
    Changes the first and last name of the current user
    
    Params:
        first_name (:class:`str`)
            The new value of the first name for the user; 1-64 characters
        
        last_name (:class:`str`)
            The new value of the optional last name for the user; 0-64 characters
        
    """

    ID: str = Field("setName", alias="@type")
    first_name: str = Field(..., min_length=1, max_length=64)
    last_name: typing.Optional[str] = Field(None, max_length=64)

    @staticmethod
    def read(q: dict) -> SetName:
        return SetName.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .draft_message import DraftMessage
from .message import Message
from .message_reply_info import MessageReplyInfo
from ..base_object import BaseObject


class MessageThreadInfo(BaseObject):
    """
    Contains information about a message thread
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat to which the message thread belongs
        
        message_thread_id (:class:`int`)
            Message thread identifier, unique within the chat
        
        reply_info (:class:`MessageReplyInfo`)
            Contains information about the message thread
        
        messages (:obj:`list[Message]`)
            The messages from which the thread starts. The messages are returned in a reverse chronological order (i.e., in order of decreasing message_id)
        
        draft_message (:class:`DraftMessage`)
            A draft of a message in the message thread; may be null
        
    """

    ID: str = Field("messageThreadInfo", alias="@type")
    chat_id: int
    message_thread_id: int
    reply_info: MessageReplyInfo
    messages: list[Message]
    draft_message: typing.Optional[DraftMessage] = None

    @staticmethod
    def read(q: dict) -> MessageThreadInfo:
        return MessageThreadInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .chat_action_bar import ChatActionBar
from .chat_notification_settings import ChatNotificationSettings
from .chat_permissions import ChatPermissions
from .chat_photo_info import ChatPhotoInfo
from .chat_position import ChatPosition
from .chat_type import ChatType
from .draft_message import DraftMessage
from .message import Message
from .voice_chat import VoiceChat
from ..base_object import BaseObject


class Chat(BaseObject):
    """
    A chat. (Can be a private chat, basic group, supergroup, or secret chat)
    
    Params:
        id (:class:`int`)
            Chat unique identifier
        
        type_ (:class:`ChatType`)
            Type of the chat
        
        title (:class:`str`)
            Chat title
        
        photo (:class:`ChatPhotoInfo`)
            Chat photo; may be null
        
        permissions (:class:`ChatPermissions`)
            Actions that non-administrator chat members are allowed to take in the chat
        
        last_message (:class:`Message`)
            Last message in the chat; may be null
        
        positions (:obj:`list[ChatPosition]`)
            Positions of the chat in chat lists
        
        is_marked_as_unread (:class:`bool`)
            True, if the chat is marked as unread
        
        is_blocked (:class:`bool`)
            True, if the chat is blocked by the current user and private messages from the chat can't be received
        
        has_scheduled_messages (:class:`bool`)
            True, if the chat has scheduled messages
        
        can_be_deleted_only_for_self (:class:`bool`)
            True, if the chat messages can be deleted only for the current user while other users will continue to see the messages
        
        can_be_deleted_for_all_users (:class:`bool`)
            True, if the chat messages can be deleted for all users
        
        can_be_reported (:class:`bool`)
            True, if the chat can be reported to Telegram moderators through reportChat or reportChatPhoto
        
        default_disable_notification (:class:`bool`)
            Default value of the disable_notification parameter, used when a message is sent to the chat
        
        unread_count (:class:`int`)
            Number of unread messages in the chat
        
        last_read_inbox_message_id (:class:`int`)
            Identifier of the last read incoming message
        
        last_read_outbox_message_id (:class:`int`)
            Identifier of the last read outgoing message
        
        unread_mention_count (:class:`int`)
            Number of unread messages with a mention/reply in the chat
        
        notification_settings (:class:`ChatNotificationSettings`)
            Notification settings for this chat
        
        message_ttl_setting (:class:`int`)
            Current message Time To Live setting (self-destruct timer) for the chat; 0 if not defined. TTL is counted from the time message or its content is viewed in secret chats and from the send date in other chats
        
        action_bar (:class:`ChatActionBar`)
            Describes actions which should be possible to do through a chat action bar; may be null
        
        voice_chat (:class:`VoiceChat`)
            Contains information about voice chat of the chat
        
        reply_markup_message_id (:class:`int`)
            Identifier of the message from which reply markup needs to be used; 0 if there is no default custom reply markup in the chat
        
        draft_message (:class:`DraftMessage`)
            A draft of a message in the chat; may be null
        
        client_data (:class:`str`)
            Contains application-specific data associated with the chat. (For example, the chat scroll position or local chat notification settings can be stored here.) Persistent if the message database is used
        
    """

    ID: str = Field("chat", alias="@type")
    id: int
    type_: ChatType = Field(..., alias='type')
    title: str
    photo: typing.Optional[ChatPhotoInfo] = None
    permissions: ChatPermissions
    last_message: typing.Optional[Message] = None
    positions: list[ChatPosition]
    is_marked_as_unread: bool
    is_blocked: bool
    has_scheduled_messages: bool
    can_be_deleted_only_for_self: bool
    can_be_deleted_for_all_users: bool
    can_be_reported: bool
    default_disable_notification: bool
    unread_count: int
    last_read_inbox_message_id: int
    last_read_outbox_message_id: int
    unread_mention_count: int
    notification_settings: ChatNotificationSettings
    message_ttl_setting: int
    action_bar: typing.Optional[ChatActionBar] = None
    voice_chat: VoiceChat
    reply_markup_message_id: int
    draft_message: typing.Optional[DraftMessage] = None
    client_data: str

    @staticmethod
    def read(q: dict) -> Chat:
        return Chat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SharePhoneNumber(BaseObject):
    """
    Shares the phone number of the current user with a mutual contact. Supposed to be called when the user clicks on chatActionBarSharePhoneNumber
    
    Params:
        user_id (:class:`int`)
            Identifier of the user with whom to share the phone number. The user must be a mutual contact
        
    """

    ID: str = Field("sharePhoneNumber", alias="@type")
    user_id: int

    @staticmethod
    def read(q: dict) -> SharePhoneNumber:
        return SharePhoneNumber.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from ..base_object import BaseObject


class SetChatDescription(BaseObject):
    """
    Changes information about a chat. Available for basic groups, supergroups, and channels. Requires can_change_info administrator right
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat
        
        param_description (:class:`str`)
            New chat description; 0-255 characters
        
    """

    ID: str = Field("setChatDescription", alias="@type")
    chat_id: int
    param_description: typing.Optional[str] = Field(None, max_length=255)

    @staticmethod
    def read(q: dict) -> SetChatDescription:
        return SetChatDescription.construct(**q)
